<?php

namespace Foo;

/**
 * class VeryLongPHP73Nowdoc { }
 */
class VeryLongPHP73Nowdoc
{
    public function test_nowdoc()
    {
        return <<<'NOWDOCPHP73'
      Leave her alone, you bastard. Ah. Whoa. Lynda, first of all, I'm not your answering service. Second of all, somebody named Greg or Craig called you just a little while ago. I hope you don't mind but George asked if he could take me home. Whoa, wait, Doc.

    I noticed you band is on the roster for dance auditions after school today. Why even bother Mcfly, you haven't got a chance, you're too much like your own man. No McFly ever amounted to anything in the history of Hill Valley. Oh, if Paul calls me tell him I'm working at the boutique late tonight. Hey, George, buddy, you weren't at school, what have you been doing all day? Doc, Doc. Oh, no. You're alive. Bullet proof vest, how did you know, I never got a chance to tell you. About all that talk about screwing up future events, the space time continuum. Listen, Doc.

    Yeah, I guessed you're a sailor, aren't you, that's why you wear that life preserver. Doc, she's beautiful. She's crazy about me. Look at this, look what she wrote me, Doc. That says it all. Doc, you're my only hope. Indeed I will, roll em. I, Doctor Emmett Brown, am about to embark on an historic journey. What have I been thinking of, I almost forgot to bring some extra plutonium. How did I ever expect to get back, one pallet one trip I must be out of my mind. What is it Einy? Oh my god, they found me, I don't know how but they found me. Run for it, Marty. I have to tell you about the future. Huh?

    Right, and where am I gonna be? Listen, this is very important, I forgot my video camera, could you stop by my place and pick it up on your way to the mall? Re-elect Mayor Goldie Wilson. Progress is his middle name. whoa, whoa Doc, stuck here, I can't be stuck here, I got a life in 1985. I got a girl. Well, uh, listen, uh, I really-

    Alright, okay listen, keep your pants on, she's over in the cafe. God, how do you do this? What made you change your mind, George? Ho, you mean you're gonna touch her on her- Well, safe and sound, now, n good old 1955. Look, George, I'm telling you George, if you do not ask Lorraine to that dance, I'm gonna regret it for the rest of my life. He's a very strange young man.

    Can I go now, Mr. Strickland? Erased from existence. You'll find out in thirty years. Whoa, they really cleaned this place up, looks brand new. Something that really cooks. Alright, alright this is an oldie, but uh, it's an oldie where I come from. Alright guys, let's do some blues riff in b, watch me for the changes, and uh, try and keep up, okay.

    Silence Earthling. my name is Darth Vader. I'm am an extra-terrestrial from the planet Vulcan. Marty, that's completely out of the question, you must not leave this house. you must not see anybody or talk to anybody. Anything you do could have serious repercussions on future events. Do you understand? McFly. The hell you doing to my car? What?

    See, there's Biff out there waxing it right now. Now, Biff, I wanna make sure that we get two coats of wax this time, not just one. Back to the future. No, get out of town, my mom thinks I'm going camping with the guys. Well, Jennifer, my mother would freak out if she knew I was going up there with you. And I get this standard lecture about how she never did that kind of stuff when she was a kid. Now look, I think she was born a nun. No no no, Doc, I just got here, okay, Jennifer's here, we're gonna take the new truck for a spin. Which one's your pop?

    My equipment, that reminds me, Marty, you better not hook up to the amplifier. There's a slight possibility for overload. 1955? You're my ma- you're my ma. Alright, good-bye Einy. Oh, watch that re-entry, it's a little bumpy. Alright, punk, now- Lorraine, are you up there?

    I have to tell you about the future. Hey, George, buddy, you weren't at school, what have you been doing all day? Yes, definitely, god-dammit George, swear. Okay, so now, you come up, you punch me in the stomach, I'm out for the count, right? And you and Lorraine live happily ever after. Uh, well, okay Biff, uh, I'll finish that on up tonight and I'll bring it over first thing tomorrow morning. No, Marty, we've already agreed that having information about the future could be extremely dangerous. Even if your intentions are good, they could backfire drastically. Whatever you've got to tell me I'll find out through the natural course of time.

    Hey, McFly, I thought I told you never to come in here. Well it's gonna cost you. How much money you got on you? My insurance, it's your car, your insurance should pay for it. Hey, I wanna know who's gonna pay for this? I spilled beer all over it when that car smashed into me. Who's gonna pay my cleaning bill? Mom, Dad. Yes, definitely, god-dammit George, swear. Okay, so now, you come up, you punch me in the stomach, I'm out for the count, right? And you and Lorraine live happily ever after. Doc, is that a de-

    Sit here, Marty. Welcome to my latest experiment. It's the one I've been waiting for all my life. Let's get him. It's information about the future isn't it. I warned you about this kid. The consequences could be disastrous. He's absolutely right, Marty. the last thing you need is headaches.

    Yeah, but I never picked a fight in my entire life. What? George, aren't you gonna kiss me? This is it. This is the answer. It says here that a bolt of lightning is gonna strike the clock tower precisely at 10:04 p.m. next Saturday night. If we could somehow harness this bolt of lightning, channel it into the flux capacitor, it just might work. Next Saturday night, we're sending you back to the future. Let him go, Biff, you're drunk.

    We all make mistakes in life, children George: you ever think of running for class president? Doc? You do? Oh, just a little weather experiment.

    The only way we're gonna get those two to successfully meet is if they're alone together. So you've got to get your father and mother to interact at some sort of social- Hey, hey, keep rolling, keep rolling there. No, no, no, no, this sucker's electrical. But I need a nuclear reaction to generate the one point twenty-one gigawatts of electricity that I need. So what's it to you, butthead. You know you've been looking for a, since you're new here, I'm gonna cut you a break, today. So why don't you make like a tree, and get out of here. Did you hurt your head? I have to tell you about the future.

    Thanks a lot, kid. What kind of date? I don't know, what do kids do in the fifties? Look, there's a rhythmic ceremonial ritual coming up. What? Where were we.

    Why is she gonna get angry with you? Save the clock tower, save the clock tower. Mayor Wilson is sponsoring an initiative to replace that clock. Thirty years ago, lightning struck that clock tower and the clock hasn't run since. We at the Hill Valley Preservation Society think it should be preserved exactly the way it is as part of our history and heritage. You know Marty, you look so familiar, do I know your mother? Marty, such a nice name. Hello.

    This is more serious than I thought. Apparently your mother is amorously infatuated with you instead of your father. He's an absolute dream. The keys are in the trunk. McFly. Listen, Doc.
    Ah, honey, your first novel. Uh, plutonium, wait a minute, are you telling me that this sucker's nuclear? Wow, you must be rich. Perfect, just perfect. Hey.

    What? Whoa, wait, Doc. I do understand. If I know too much about my own future I could endanger my own existence, just as you endangered yours. The only way we're gonna get those two to successfully meet is if they're alone together. So you've got to get your father and mother to interact at some sort of social- Doc, you don't just walk into a store and ask for plutonium. Did you rip this off?

    Well, they're bigger than me. You don't understand. Oh, you mean how you're supposed to act on a first date. Doc. I over slept, look I need your help. I have to ask Lorraine out but I don't know how to do it. I have to ask Lorraine out but I don't know how to do it.

    Well, Marty, I'm almost eighteen-years-old, it's not like I've never parked before. Well, Marty, I want to thank you for all your good advice, I'll never forget it. I guess you guys aren't ready for that yet. But your kids are gonna love it. He's an absolute dream. What the hell is a gigawatt?

    Let him go, Biff, you're drunk. Marty, you didn't fall asleep, did you? Shut your filthy mouth, I'm not that kind of girl. Now, Biff, um, can I assume that your insurance is gonna pay for the damage? No, bastards.

    Oh, I've been so worried about you ever since you ran off the other night. Are you okay? I'm sorry I have to go. Isn't he a dream boat? Uh Doc, uh no. No, don't be silly. I guarantee it. Um, yeah, I'm on my way. Don't tell me anything.

    The way I see it, if you're gonna build a time machine into a car why not do it with some style. Besides, the stainless, steel construction made the flux dispersal- look out. Marty, why are you so nervous? What, what? We're gonna take a little break but we'll be back in a while so, don't nobody go no where. Yeah, alright, bye-bye. What?

    Just finishing up the second coat now. Alright, okay Jennifer. What if I send in the tape and they don't like it. I mean, what if they say I'm no good. What if they say, 'Get out of here, kid, you got no future.' I mean, I just don't think I can take that kind of rejection. Jesus, I'm beginning to sound like my old man. Uh, well, I haven't finished those up yet, but you know I figured since they weren't due till- I said the keys are in here. Maybe you were adopted.

    Watch this. Not me, the car, the car. My calculations are correct, when this baby hits eighty-eight miles per hour, your gonna see some serious shit. Watch this, watch this. Ha, what did I tell you, eighty-eight miles per hour. The temporal displacement occurred at exactly 1:20 a.m. and zero seconds. Stop it. You extol me with a lot of confidence, Doc. Oh, what I meant to day was- Uh, Doc.

    Alright, we're the pinheads. And he could sleep in my room. I know, and all I could say is I'm sorry. I'm really gonna miss you. Doc, about the future- Lorraine.

    The only way we're gonna get those two to successfully meet is if they're alone together. So you've got to get your father and mother to interact at some sort of social- Hey George, buddy, hey, I've been looking all over for you. You remember me, the guy who saved your life the other day. Radiation suit, of course, cause all of the fall out from the atomic wars. This is truly amazing, a portable television studio. No wonder your president has to be an actor, he's gotta look good on television. Doc, Doc. Oh, no. You're alive. Bullet proof vest, how did you know, I never got a chance to tell you. About all that talk about screwing up future events, the space time continuum. Yeah, I'm- mayor. Now that's a good idea. I could run for mayor.

    Don't tell me anything. What's a rerun? whoa, this is it, this is the part coming up, Doc. Well, now we gotta sneak this back into my laboratory, we've gotta get you home. Nothing.

    Go. Go. What the hell is a gigawatt? Science Fiction Theater. Precisely. Like I always told you, if you put your mind to it you could accomplish anything.

    Right. Ohh, no. Yeah, who are you? I can't play. I followed you.

    I don't know, Doc, I guess she felt sorry for him cause her did hit him with the car, hit me with the car. Evening, Doctor Brown, what's with the wire? oh yeah, all you gotta do is go over there and ask her. Marty, I always wear a suit to the office. You alright? Uh, yeah.

    I still don't understand, how am I supposed to go to the dance with her, if she's already going to the dance with you. Alright, we're the pinheads. Let's get him. Ronald Reagon, the actor? Then who's vice president, Jerry Lewis? I suppose Jane Wymann is the first lady. I have to tell you about the future.

    Next, please. Perfect, just perfect. Doc, you don't just walk into a store and ask for plutonium. Did you rip this off? Calvin. Hi, it's really a pleasure to meet you.

    That's a Florence Nightingale effect. It happens in hospitals when nurses fall in love with their patients. Go to it, kid. So tell me, Marty, how long have you been in port? Don't pay any attention to him, he's in one of his moods. Sam, quit fiddling with that thing, come in here to dinner. Now let's see, you already know Lorraine, this is Milton, this is Sally, that's Toby, and over there in the playpen is little baby Joey. Wait a minute, wait a minute. 1:15 in the morning? So tell me, future boy, who's president of the United States in 1985?

    Oh, great scott. You get the cable, I'll throw the rope down to you. George. Whoa, whoa, Biff, what's that? That's true, Marty, I think you should spend the night. I think you're our responsibility. Yet.

    Now that's a risk you'll have to take you're life depends on it. George. Hey. It's my dad. Oh, I've been so worried about you ever since you ran off the other night. Are you okay? I'm sorry I have to go. Isn't he a dream boat?

    Look, George, I'm telling you George, if you do not ask Lorraine to that dance, I'm gonna regret it for the rest of my life. Don't say a word. Shape up, man. You're a slacker. You wanna be a slacker for the rest of your life? What did your mother ever see in that kid? Hey, Doc, we better back up, we don't have enough roads to get up to 88.

    Erased from existence. Right. Don't say a word. He's absolutely right, Marty. the last thing you need is headaches. Hey, Doc? Doc. Hello, anybody home? Einstein, come here, boy. What's going on? Wha- aw, god. Aw, Jesus. Whoa, rock and roll. Yo

    Ho, you mean you're gonna touch her on her- Yeah, it's in the back. Precisely. Hey Marty, I'm not your answering service, but you're outside pouting about the car, Jennifer Parker called you twice. Where the hell are they.

    What you got under here? Yet. Doc? Lorraine, have you ever, uh, been in a situation where you know you had to act a certain way but when you got there, you didn't know if you could go through with it? Mother, with Marty's parents out of town, don't you think he oughta spend the night, after all, Dad almost killed him with the car.

    Ah. Whoa. Are you sure about this storm? It's safe now. Everything's lead lined. Don't you lose those tapes now, we'll need a record. Wup, wup, I almost forgot my luggage. Who knows if they've got cotton underwear in the future. I'm allergic to all synthetics. We all make mistakes in life, children Leave me alone.

    Look, you gotta listen to me. Go. Now, Biff, um, can I assume that your insurance is gonna pay for the damage? Crazy drunk drivers. Hey man, look at Marvin's hand. He can't play with his hands like that, and we can't play without him.

    Calvin. Listen, Doc. Uh, Lorraine. How did you know I was here? Of course, the Enchantment Under The Sea Dance they're supposed to go to this, that's where they kiss for the first time. You broke it. Wow, look at him go.

    Look, I'm just not ready to ask Lorraine out to the dance, and not you, nor anybody else on this planet is gonna make me change my mind. No, Doc. Wait a minute, Doc. What are you talking about? What happens to us in the future? What do we become assholes or something? Listen, woh. Hello, uh excuse me. Sorry about your barn. Okay, alright, Saturday is good, Saturday's good, I could spend a week in 1955. I could hang out, you could show me around.

    Flux capacitor. Oh, I sure like her, Marty, she is such a sweet girl. Isn't tonight the night of the big date? Kids, we're gonna have to eat this cake by ourselves, Uncle Joey didn't make parole again. I think it would be nice, if you all dropped him a line. Oh, you make it sound so easy. I just, I wish I wasn't so scared. Yeah, I'll keep that in mind.

    I don't wanna see you in here again. Something that really cooks. Alright, alright this is an oldie, but uh, it's an oldie where I come from. Alright guys, let's do some blues riff in b, watch me for the changes, and uh, try and keep up, okay. What was it, George, bird watching? The hell you doing to my car? Yeah, well, I still don't understand what Dad was doing in the middle of the street.

    Right about here. Good evening, I'm Doctor Emmet Brown, I'm standing here on the parking lot of- This Saturday night, mostly clear, with some scattered clouds. Lows in the upper forties. My equipment, that reminds me, Marty, you better not hook up to the amplifier. There's a slight possibility for overload. Never?

    Well, Marty, I want to thank you for all your good advice, I'll never forget it. Oh, great scott. You get the cable, I'll throw the rope down to you. The future, it's where you're going? Okay, but I don't know what to say. Tab? I can't give you a tab unless you order something.

    I think you got the wrong car, McFly. My god, do you know what this means? It means that this damn thing doesn't work at all. It's taken me almost thirty years and my entire family fortune to realize the vision of that day, my god has it been that long. Things have certainly changed around here. I remember when this was all farmland as far as the eye could see. Old man Peabody, owned all of this. He had this crazy idea about breeding pine trees. Alright, okay listen, keep your pants on, she's over in the cafe. God, how do you do this? What made you change your mind, George? I'm sure that in 1985, plutonium is available at every corner drug store, but in 1955, it's a little hard to come by. Marty, I'm sorry, but I'm afraid you're stuck here.

    David, watch your mouth. You come here and kiss your mother before you go, come here. So what's it to you, butthead. You know you've been looking for a, since you're new here, I'm gonna cut you a break, today. So why don't you make like a tree, and get out of here. Ah. Its good. It's uh, the other end of town, a block past Maple.

    Who is that guy. Unfortunately no, it requires something with a little more kick, plutonium. Nothing. Hey wait, wait a minute, who are you? Stella, another one of these damn kids jumped in front of my car. Come on out here, help me take him in the house. Doc, is that a de-

    I think you got the wrong car, McFly. My insurance, it's your car, your insurance should pay for it. Hey, I wanna know who's gonna pay for this? I spilled beer all over it when that car smashed into me. Who's gonna pay my cleaning bill? Pretty Mediocre photographic fakery, they cut off your brother's hair. Don't stop, Wilbert, drive. I hope so.

    Save the clock tower, save the clock tower. Mayor Wilson is sponsoring an initiative to replace that clock. Thirty years ago, lightning struck that clock tower and the clock hasn't run since. We at the Hill Valley Preservation Society think it should be preserved exactly the way it is as part of our history and heritage. Uh no, not hard at all. So anyway, George, now Lorraine, she really likes you. She told me to tell you that she wants you to ask her to the Enchantment Under The Sea Dance. Biff. George. George. How could I have been so careless. One point twenty-one gigawatts. Tom, how am I gonna generate that kind of power, it can't be done, it can't.

    He's fine, and he's completely unaware that anything happened. As far as he's concerned the trip was instantaneous. That's why Einstein's watch is exactly one minute behind mine. He skipped over that minute to instantly arrive at this moment in time. Come here, I'll show you how it works. First, you turn the time circuits on. This readout tell you where you're going, this one tells you where you are, this one tells you where you were. You imput the destination time on this keypad. Say, you wanna see the signing of the declaration of independence, or witness the birth or Christ. Here's a red-letter date in the history of science, November 5, 1955. Yes, of course, November 5, 1955. Y'know this time it wasn't my fault. The Doc set all of his clocks twenty-five minutes slow. Where? Radiation suit, of course, cause all of the fall out from the atomic wars. This is truly amazing, a portable television studio. No wonder your president has to be an actor, he's gotta look good on television. Thanks.

    Yeah well look, Marvin, Marvin, you gotta play. See that's where they kiss for the first time on the dance floor. And if there's no music, they can't dance, and if they can't dance, they can't kiss, and if they can't kiss, they can't fall in love and I'm history. I'd like you to meet my good friend George McFly. Ronald Reagon. Alright, let's set your destination time. This is the exact time you left. I'm gonna send you back at exactly the same time. It's be like you never left. Now, I painted a white line on the street way over there, that's where you start from. I've calculated the distance and wind resistance fresh to active from the moment the lightning strikes, at exactly 7 minutes and 22 seconds. When this alarm goes off you hit the gas. 1955? You're my ma- you're my ma.

    Hi, Marty. I don't like her, Marty. Any girl who calls a boy is just asking for trouble. Precisely. Whoa, this is heavy. My insurance, it's your car, your insurance should pay for it. Hey, I wanna know who's gonna pay for this? I spilled beer all over it when that car smashed into me. Who's gonna pay my cleaning bill?

    Lorraine. Yeah, I think maybe you do. Right, I got it. Nothing. I'll be at my grandma's. Here, let me give you the number. Bye.

    I gotta go, uh, I gotta go. Thanks very much, it was wonderful, you were all great. See you all later, much later. I know, and all I could say is I'm sorry. I'm gonna be at the dance. You're gonna be in the car with her. I got enough practical jokes for one evening. Good night, future boy.

    Go. Re-elect Mayor Goldie Wilson. Progress is his middle name. Jesus, you smoke too? Oh, what I meant to day was- Dear Doctor Brown, on the night that I go back in time, you will be shot by terrorists. Please take whatever precautions are necessary to prevent this terrible disaster. Your friend, Marty.

    Oh, what I meant to day was- Something that really cooks. Alright, alright this is an oldie, but uh, it's an oldie where I come from. Alright guys, let's do some blues riff in b, watch me for the changes, and uh, try and keep up, okay. That's him. George. It's a board with wheels.

    Uh, coast guard. Where? Can I go now, Mr. Strickland? That's for messing up my hair. Last night, Darth Vader came down from planet Vulcan. And he told me that if I didn't take Lorraine, that he'd melt my brain.

    Leave her alone, you bastard. Hey, hey, I've seen this one, I've seen this one. This is a classic, this is where Ralph dresses up as the man from space. Unroll their fire. Lorenzo, where're you keys? C'mon, open up, let me out of here, Yo.

    I, I don't know. Now Biff, don't con me. Cause, George, she wants to go to the dance with you, she just doesn't know it yet. That's why we got to show her that you, George McFly, are a fighter. You're somebody who's gonna stand up for yourself, someone who's gonna protect her. Doc? Leave her alone, you bastard.

    Doc. Now, of course not, Biff, now, I wouldn't want that to happen. Uh listen, do you know where Riverside Drive is? Hello, hello, anybody home? Think, McFly, think. I gotta have time to recopy it. Do your realize what would happen if I hand in my homework in your handwriting? I'd get kicked out of school. You wouldn't want that to happen would you, would you? Right.

    You know, Doc, you left your equipment on all week. Oh. What did you sleep in your clothes again last night. What did she say? It's your mom, she's tracked you down. Quick, let's cover the time machine. Uh, I think so.

    What, well you mean like a date? Hi, it's really a pleasure to meet you. Yeah, where does he live? Leave me alone. Well just gimme something without any sugar in it, okay?

    Quiet down, I'm sure the car is fine. you guys look great. Mom, you look so thin. Now, Biff, um, can I assume that your insurance is gonna pay for the damage? Excuse me. Radiation suit, of course, cause all of the fall out from the atomic wars. This is truly amazing, a portable television studio. No wonder your president has to be an actor, he's gotta look good on television.

    Look, I'm just not ready to ask Lorraine out to the dance, and not you, nor anybody else on this planet is gonna make me change my mind. This Saturday night, mostly clear, with some scattered clouds. Lows in the upper forties. I just wanna use the phone. oh yeah, all you gotta do is go over there and ask her. Huh?

    Listen, Doc. That was so stupid, Grandpa hit him with the car. We never would have fallen in love. Uh, I think so. Thanks a lot, kid.

    Don't tell me anything. Um, yeah well I might have sort of ran into my parents. Shut your filthy mouth, I'm not that kind of girl. Listen, I gotta go but I wanted to tell you that it's been educational. Now remember, according to my theory you interfered with with your parent's first meeting. They don't meet, they don't fall in love, they won't get married and they wont have kids. That's why your older brother's disappeared from that photograph. Your sister will follow and unless you repair the damages, you will be next.

    Why am I always the last one to know about these things. Oh, yeah, yeah. Where's Einstein, is he with you? Don't pay any attention to him, he's in one of his moods. Sam, quit fiddling with that thing, come in here to dinner. Now let's see, you already know Lorraine, this is Milton, this is Sally, that's Toby, and over there in the playpen is little baby Joey. Yeah, I guessed you're a sailor, aren't you, that's why you wear that life preserver.

    Uh listen, do you know where Riverside Drive is? You bet. Whoa, this is heavy. My god, do you know what this means? It means that this damn thing doesn't work at all. Hey I'm talking to you, McFly, you Irish bug.

    So you're my Uncle Joey. Better get used to these bars, kid. Marty, will we ever see you again? C'mon, more, dammit. Jeez. Holy shit. Let's see if you bastards can do ninety. He's a very strange young man. The car, Dad, I mean He wrecked it, totaled it. I needed that car tomorrow night, Dad, I mean do you have any idea how important this was, do you have any clue?

    Um, yeah well I might have sort of ran into my parents. Crazy drunk drivers. Right, gimme a Pepsi free. Check out that four by four. That is hot. Someday, Jennifer, someday. Wouldn't it be great to take that truck up to the lake. Throw a couple of sleeping bags in the back. Lie out under the stars. Hey, not too early I sleep in on Saturday. Oh, McFly, your shoe's untied. Don't be so gullible, McFly. You got the place fixed up nice, McFly. I have you're car towed all the way to your house and all you've got for me is light beer. What are you looking at, butthead. Say hi to your mom for me.

    Doc, look, all we need is a little plutonium. Yeah, gimme a Tab. Okay, alright, Saturday is good, Saturday's good, I could spend a week in 1955. I could hang out, you could show me around. My god, it's my mother. Put your pants back on. Thank you, don't forget to take a flyer.

    Why is she gonna get angry with you? Whoa, whoa, okay. It's uh, the other end of town, a block past Maple. David, watch your mouth. You come here and kiss your mother before you go, come here. What the hell is a gigawatt?

    Right, gimme a Pepsi free. The flux capacitor. Well, uh, listen, uh, I really- Right, I got it. Did you hurt your head?

    Oh. Yes, definitely, god-dammit George, swear. Okay, so now, you come up, you punch me in the stomach, I'm out for the count, right? And you and Lorraine live happily ever after. I will. Say that again. Just relax now Calvin, you've got a big bruise on you're head.

    Of course, the Enchantment Under The Sea Dance they're supposed to go to this, that's where they kiss for the first time. Great good, good, Lorraine, I had a feeling about you two. Hey wait, wait a minute, who are you? Stella, another one of these damn kids jumped in front of my car. Come on out here, help me take him in the house. Okay, alright, I'll prove it to you. Look at my driver's license, expires 1987. Look at my birthday, for crying out load I haven't even been born yet. And, look at this picture, my brother, my sister, and me. Look at the sweatshirt, Doc, class of 1984. I guarantee it.

    What, well you mean like a date? Kids, we're gonna have to eat this cake by ourselves, Uncle Joey didn't make parole again. I think it would be nice, if you all dropped him a line. McFly. Good, there's somebody I'd like you to meet. Lorraine. Shape up, man. You're a slacker. You wanna be a slacker for the rest of your life?

    Lorenzo, where're you keys? C'mon. I've gotta go. I'm too loud. I can't believe it. I'm never gonna get a chance to play in front of anybody. Why do you keep following me around?

    Good, I'll see you tonight. Don't forget, now, 1:15 a.m., Twin Pines Mall. Like I always told you, if you put your mind to it you could accomplish anything. Welcome to my latest experiment. It's the one I've been waiting for all my life. I'm gonna get that son-of-a-bitch. I'm gonna ram him.

    Uh? Doc, look, all we need is a little plutonium. The only way we're gonna get those two to successfully meet is if they're alone together. So you've got to get your father and mother to interact at some sort of social- Back to the future. Get out of town, I didn't know you did anything creative. Ah, let me read some.

    Hey, McFly, I thought I told you never to come in here. Well it's gonna cost you. How much money you got on you? Doc, look, all we need is a little plutonium. Where were we. Wow, ah Red, you look great. Everything looks great. 1:24, I still got time. Oh my god. No, no not again, c'mon, c'mon. Hey. Libyans. Doc, she's beautiful. She's crazy about me. Look at this, look what she wrote me, Doc. That says it all. Doc, you're my only hope.

    Well, they're your parents, you must know them. What are their common interests, what do they like to do together? Well yeah, you know we have two of them. whoa, whoa Doc, stuck here, I can't be stuck here, I got a life in 1985. I got a girl. Where? Well just gimme something without any sugar in it, okay?

    Go. Jennifer. Lorraine, are you up there? Hello. Listen, I gotta go but I wanted to tell you that it's been educational.

    Ahh. Hey wait, wait a minute, who are you? Stella, another one of these damn kids jumped in front of my car. Come on out here, help me take him in the house. Where does he come from? Yeah, he's right here. That's true, Marty, I think you should spend the night. I think you're our responsibility.

    Lorenzo, where're you keys? Cause, George, she wants to go to the dance with you, she just doesn't know it yet. That's why we got to show her that you, George McFly, are a fighter. You're somebody who's gonna stand up for yourself, someone who's gonna protect her. No, Doc. I, I don't know. Oh, uh, this is my Doc, Uncle, Brown.

    What a nightmare. I don't know, but I'm gonna find out. Great Scott. Let me see that photograph again of your brother. Just as I thought, this proves my theory, look at your brother. Hey, Doc? Doc. Hello, anybody home? Einstein, come here, boy. What's going on? Wha- aw, god. Aw, Jesus. Whoa, rock and roll. Yo Oh, you mean how you're supposed to act on a first date.

    George, help me, please. Doc, you gotta help me. you were the only one who knows how your time machine works. On the night I go back in time, you get- Doc. I have to tell you about the future. Uh listen, do you know where Riverside Drive is?

    And he could sleep in my room. How's your head? Ahh. Doc, you gotta help me. you were the only one who knows how your time machine works. But, what are you blind McFly, it's there. How else do you explain that wreck out there?

    I know, and all I could say is I'm sorry. Right. Tab? I can't give you a tab unless you order something. Of course, the Enchantment Under The Sea Dance they're supposed to go to this, that's where they kiss for the first time. Yeah but George, Lorraine wants to go with you. Give her a break.

    I, I don't know. You do? No no no this sucker's electrical, but I need a nuclear reaction to generate the one point twenty-one gigawatts of electricity that I need. Yeah well, I saw it on a rerun. No, I refuse to except the responsibility.

    That's good advice, Marty. No, Doc. Thank you, don't forget to take a flyer. Alright, good-bye Einy. Oh, watch that re-entry, it's a little bumpy. The only way we're gonna get those two to successfully meet is if they're alone together. So you've got to get your father and mother to interact at some sort of social-

    Let me show you my plan for sending you home. Please excuse the crudity of this model, I didn't have time to build it to scale or to paint it. I hope so. Well, they're bigger than me. Hi, it's really a pleasure to meet you. Alright, c'mon, I think we're safe.

    Something that really cooks. Alright, alright this is an oldie, but uh, it's an oldie where I come from. Alright guys, let's do some blues riff in b, watch me for the changes, and uh, try and keep up, okay. But you're good, Marty, you're really good. And this audition tape of your is great, you gotta send it in to the record company. It's like Doc's always saying. I'll get it back to you, alright? You cost three-hundred buck damage to my car, you son-of-a-bitch. And I'm gonna take it out of your ass. Hold him. Excuse me.

    Listen, I gotta go but I wanted to tell you that it's been educational. Right, gimme a Pepsi free. I guess you guys aren't ready for that yet. But your kids are gonna love it. Perfect, just perfect. That's Calvin Klein, oh my god, he's a dream.

    She's just trying to keep you respectable. Yeah, I'll keep that in mind. You wanna a Pepsi, pall, you're gonna pay for it. Okay, real mature guys. Okay, Biff, will you pick up my books? Oh, you mean how you're supposed to act on a first date.

    What do you mean you've seen this, it's brand new. What's a rerun? Do you mind if we park for a while? Doc, Doc. Oh, no. You're alive. Bullet proof vest, how did you know, I never got a chance to tell you. About all that talk about screwing up future events, the space time continuum. I swiped it from the old lady's liquor cabinet.

    Marty, I'm sorry, but the only power source capable of generating one point twenty-one gigawatts of electricity is a bolt of lightning. A colored mayor, that'll be the day. Are you okay? I hope so. Well looky what we have here. No no no, you're staying right here with me.

    Indeed I will, roll em. I, Doctor Emmett Brown, am about to embark on an historic journey. What have I been thinking of, I almost forgot to bring some extra plutonium. How did I ever expect to get back, one pallet one trip I must be out of my mind. What is it Einy? Oh my god, they found me, I don't know how but they found me. Run for it, Marty. Why do you keep following me around? Well, because George, nice girls get angry when guys take advantage of them. Well uh, good, fine. Now that's a risk you'll have to take you're life depends on it.

    C'mon. Oh, you make it sound so easy. I just, I wish I wasn't so scared. What a nightmare. Look, you gotta listen to me. Like I always told you, if you put your mind to it you could accomplish anything.

    Thanks. Mother, with Marty's parents out of town, don't you think he oughta spend the night, after all, Dad almost killed him with the car. What the hell is this? Right. Lou, gimme a milk, chocolate. Lorraine, my density has popped me to you. Well, aren't you going up to the lake tonight, you've been planning it for two weeks.

    Say that again. What? Hey, Doc? Doc. Hello, anybody home? Einstein, come here, boy. What's going on? Wha- aw, god. Aw, Jesus. Whoa, rock and roll. Yo That Biff, what a character. Always trying to get away with something. Been on top of Biff ever since high school. Although, if it wasn't for him- Lorraine, have you ever, uh, been in a situation where you know you had to act a certain way but when you got there, you didn't know if you could go through with it?

    Oh, yeah, yeah. Good morning, Mom. Oh, Marty, I almost forgot, Jennifer Parker called. Did you hurt your head? Good. Have a good trip Einstein, watch your head. I need fuel. Go ahead, quick, get in the car.

    Well, Marty, I want to thank you for all your good advice, I'll never forget it. Shut your filthy mouth, I'm not that kind of girl. One point twenty-one gigawatts. One point twenty-one gigawatts. Great Scott. Hi, Marty. Oh.

    It's a board with wheels. Right. Let's put him in there. My god, do you know what this means? It means that this damn thing doesn't work at all. Uh, look me up when you get there.

    Lynda, first of all, I'm not your answering service. Second of all, somebody named Greg or Craig called you just a little while ago. Save the clock tower, save the clock tower. Mayor Wilson is sponsoring an initiative to replace that clock. Thirty years ago, lightning struck that clock tower and the clock hasn't run since. We at the Hill Valley Preservation Society think it should be preserved exactly the way it is as part of our history and heritage. Right. whoa, this is it, this is the part coming up, Doc. Doc?

    Oh, I've been so worried about you ever since you ran off the other night. Are you okay? I'm sorry I have to go. Isn't he a dream boat? Yeah. Just relax now Calvin, you've got a big bruise on you're head. Save the clock tower. Silence Earthling. my name is Darth Vader. I'm am an extra-terrestrial from the planet Vulcan.

    Yeah well, I saw it on a rerun. Yeah. Why that's me, look at me, I'm an old man. No sir, I'm gonna make something out of myself, I'm going to night school and one day I'm gonna be somebody. Doc.

    Yeah, well uh, lets keep this brain melting stuff to ourselves, okay? Sam, quit fiddling with that thing and come in here and eat your dinner. Alright, we're the pinheads. Will you take care of that? Give me a hand, Lorenzo. Ow, dammit, man, I sliced my hand.

    Mayor Goldie Wilson, I like the sound of that. Yeah, you got my homework finished, McFly? Oh, just a little weather experiment. Marty, I'm sorry, but the only power source capable of generating one point twenty-one gigawatts of electricity is a bolt of lightning. Evening, Doctor Brown, what's with the wire?

    Mother, with Marty's parents out of town, don't you think he oughta spend the night, after all, Dad almost killed him with the car. Good, you could start by sweeping the floor. I have a feeling too. Why am I always the last one to know about these things. Why not?

    This is it. This is the answer. It says here that a bolt of lightning is gonna strike the clock tower precisely at 10:04 p.m. next Saturday night. If we could somehow harness this bolt of lightning, channel it into the flux capacitor, it just might work. Next Saturday night, we're sending you back to the future. It's taken me almost thirty years and my entire family fortune to realize the vision of that day, my god has it been that long. Things have certainly changed around here. I remember when this was all farmland as far as the eye could see. Old man Peabody, owned all of this. He had this crazy idea about breeding pine trees. Quiet down, I'm sure the car is fine. But you're good, Marty, you're really good. And this audition tape of your is great, you gotta send it in to the record company. It's like Doc's always saying. Well uh, good, fine.

    Oh. What the hell is a gigawatt? Unroll their fire. Nothing. Well that's your name, isn't it? Calvin Klein. it's written all over your underwear. Oh, I guess they call you Cal, huh?

    Hi, it's really a pleasure to meet you. Well, what if they didn't like them, what if they told me I was no good. I guess that would be pretty hard for somebody to understand. Excuse me. Look, George, I'm telling you George, if you do not ask Lorraine to that dance, I'm gonna regret it for the rest of my life. Marty, don't be such a square. Everybody who's anybody drinks.

    That's a Florence Nightingale effect. It happens in hospitals when nurses fall in love with their patients. Go to it, kid. I guess you guys aren't ready for that yet. But your kids are gonna love it. whoa, whoa Doc, stuck here, I can't be stuck here, I got a life in 1985. I got a girl. Of course, the Enchantment Under The Sea Dance they're supposed to go to this, that's where they kiss for the first time. I can't play.

    Where were we. Don't worry, I'll take care of the lightning, you take care of your pop. By the way, what happened today, did he ask her out? Whoa, whoa, kid, kid, stop, stop, stop, stop. What Lorraine, what? Well, what if they didn't like them, what if they told me I was no good. I guess that would be pretty hard for somebody to understand.

    The appropriate question is, weren't the hell are they. Einstein has just become the world's first time traveler. I sent him into the future. One minute into the future to be exact. And at exactly 1:21 a.m. we should cat h up with him and the time machine. Alright, okay listen, keep your pants on, she's over in the cafe. God, how do you do this? What made you change your mind, George? Don't stop, Wilbert, drive. Yeah, it's 8:00. Hey c'mon, I had to change, you think I'm going back in that zoot suit? The old man really came through it worked.

    Calvin, why do you keep calling me Calvin? A block passed Maple, that's John F. Kennedy Drive. Oh, hi , Marty. I didn't hear you come in. Fascinating device, this video unit. Which one's your pop? Jennifer.

    Oh, no no no, I never uh, I never let anybody read my stories. Well, you mean, it makes perfect sense. Well, I guess that's everything. Uh, well, I gotta go. Alright, we're the pinheads.

    Sit here, Marty. See, there's Biff out there waxing it right now. Now, Biff, I wanna make sure that we get two coats of wax this time, not just one. Over there, on my hope chest. I've never seen purple underwear before, Calvin. Good, I'll see you tonight. Don't forget, now, 1:15 a.m., Twin Pines Mall. Your, your right.

    Look me up when you get there, guess I'll be about 47. Wait a minute, wait a minute. 1:15 in the morning? Marty, that's completely out of the question, you must not leave this house. you must not see anybody or talk to anybody. Anything you do could have serious repercussions on future events. Do you understand? My name's Lorraine, Lorraine Baines. Good. Have a good trip Einstein, watch your head.

    Ahh. Ahh. I have to tell you about the future. McFly. What Lorraine, what? No, get out of town, my mom thinks I'm going camping with the guys. Well, Jennifer, my mother would freak out if she knew I was going up there with you. And I get this standard lecture about how she never did that kind of stuff when she was a kid. Now look, I think she was born a nun.

    Whoa, this is heavy. Radiation suit, of course, cause all of the fall out from the atomic wars. This is truly amazing, a portable television studio. No wonder your president has to be an actor, he's gotta look good on television. Yeah. You're gonna break his arm. Biff, leave him alone. Let him go. Let him go. Right, I got it.

    Alright, McFly, you're asking for it, and now you're gonna get it. Yeah, exactly. You okay, is everything alright? This is uh, this is heavy duty, Doc, this is great. Uh, does it run on regular unleaded gasoline? Don't tell me anything.

    And Jack Benny is secretary of the Treasury. Uh, plutonium, wait a minute, are you telling me that this sucker's nuclear? You know, Doc, you left your equipment on all week. He laid out Biff in one punch. I never knew he had it in him. He never stood up to Biff in his life. Unfortunately no, it requires something with a little more kick, plutonium.

    Wrecked? When did this happen and- Whoa, wait a minute, Doc, are you telling me that my mother has got the hots for me? Where the hell are they. Yeah, well, I still don't understand what Dad was doing in the middle of the street. Tab? I can't give you a tab unless you order something.

    Go. Go. you guys look great. Mom, you look so thin. George. George. Go. Breakfast.

    Wow, ah Red, you look great. Everything looks great. 1:24, I still got time. Oh my god. No, no not again, c'mon, c'mon. Hey. Libyans. Say, why do you let those boys push you around like that? Yeah, well, I still don't understand what Dad was doing in the middle of the street. Looks like a airplane, without wings. Uh, stories, science fiction stories, about visitors coming down to Earth from another planet.

    Hey guys, you gotta get back in there and finish the dance. Can I go now, Mr. Strickland? Doc, she didn't even look at him. It's about the future, isn't it? Einstein, hey Einstein, where's the Doc, boy, huh? Doc

    Dammit, Doc, why did you have to tear up that letter? If only I had more time. Wait a minute, I got all the time I want I got a time machine, I'll just go back and warn him. 10 minutes oughta do it. Time-circuits on, flux-capacitor fluxing, engine running, alright. No, no no no no, c'mon c'mon. C'mon c'mon, here we go, this time. Please, please, c'mon. Look, you gotta listen to me. Uh, well, actually, I figured since it wasn't due till Monday- No, Marty, we've already agreed that having information about the future could be extremely dangerous. Even if your intentions are good, they could backfire drastically. Whatever you've got to tell me I'll find out through the natural course of time. What kind of date? I don't know, what do kids do in the fifties?

    Holy shit. Of course I do. Just a second, let's see if I could find it. Marty, you made it. What was it, George, bird watching? Wait a minute, wait a minute, Doc, are you telling me that you built a time machine out of a delorean.

    Yeah Mom, we know, you've told us this story a million times. You felt sorry for him so you decided to go with him to The Fish Under The Sea Dance. But, what are you blind McFly, it's there. How else do you explain that wreck out there? Marty, you seem so nervous, is something wrong? Yeah, I think it's a major embarrassment having an uncle in prison. And where's my reports?

    He's a very strange young man. I do understand. If I know too much about my own future I could endanger my own existence, just as you endangered yours. Well, this is a radiation suit. Uh, well, okay Biff, uh, I'll finish that on up tonight and I'll bring it over first thing tomorrow morning. Something that really cooks. Alright, alright this is an oldie, but uh, it's an oldie where I come from. Alright guys, let's do some blues riff in b, watch me for the changes, and uh, try and keep up, okay.

    What you got under here? You guys, take him in back and I'll be right there. Well c'mon, this ain't no peep show. Wait a minute, what are you doing, Doc? No no no, Doc, I just got here, okay, Jennifer's here, we're gonna take the new truck for a spin. Alright, punk, now-

    Believe me, Marty, you're better off not having to worry about all the aggravation and headaches of playing at that dance. What were you doing in the middle of the street, a kid your age. Oh honey, he's teasing you, nobody has two television sets. So tell me, future boy, who's president of the United States in 1985? You know what I do in those situations?

    Now which one was it, Greg or Craig? Uh, well, actually, I figured since it wasn't due till Monday- No no no this sucker's electrical, but I need a nuclear reaction to generate the one point twenty-one gigawatts of electricity that I need. I'm too loud. I can't believe it. I'm never gonna get a chance to play in front of anybody. Ah.

    Yeah. It's information about the future isn't it. I warned you about this kid. The consequences could be disastrous. I know, and all I could say is I'm sorry. Good morning, Mom. Oh, Marty, I almost forgot, Jennifer Parker called. Excuse me.

    Whoa, this is heavy. That's him. That's right, he's gonna be mayor. Oh no, don't touch that. That's some new specialized weather sensing equipment. Ronald Reagon, the actor? Then who's vice president, Jerry Lewis? I suppose Jane Wymann is the first lady.

    Marty, you're beginning to sound just like my mother. We never would have fallen in love. Now that's a risk you'll have to take you're life depends on it. Yeah, but you're uh, you're so, you're so thin. Well just gimme something without any sugar in it, okay?

    You guys, take him in back and I'll be right there. Well c'mon, this ain't no peep show. Alright, punk, now- Alright, okay. Alright, there she is, George. Just go in there and invite her. Yeah, who are you? Oh, hi , Marty. I didn't hear you come in. Fascinating device, this video unit.

    C'mon, open up, let me out of here, Yo. You have this thing hooked up to the car? Maybe you were adopted. Okay, alright, Saturday is good, Saturday's good, I could spend a week in 1955. I could hang out, you could show me around. Why is she gonna get angry with you?

    Doc. It's uh, the other end of town, a block past Maple. Oh honey, he's teasing you, nobody has two television sets. Okay, that's enough. Now stop the microphone. I'm sorry fellas. I'm afraid you're just too darn loud. Next, please. Where's the next group, please. Yeah, I'm- mayor. Now that's a good idea. I could run for mayor.

    Yeah, sure, okay. Oh, uh, this is my Doc, Uncle, Brown. What's the meaning of this. Ho, you mean you're gonna touch her on her- What, well you mean like a date?

    What's that thing he's on? Um, well it's a delorean, right? Shape up, man. You're a slacker. You wanna be a slacker for the rest of your life? Okay. Yeah, it's 8:00.

    The appropriate question is, weren't the hell are they. Einstein has just become the world's first time traveler. I sent him into the future. One minute into the future to be exact. And at exactly 1:21 a.m. we should cat h up with him and the time machine. Who are you? Uh, plutonium, wait a minute, are you telling me that this sucker's nuclear? That's right, twenty five years into the future. I've always dreamed on seeing the future, looking beyond my years, seeing the progress of mankind. I'll also be able to see who wins the next twenty-five world series. Yes, definitely, god-dammit George, swear. Okay, so now, you come up, you punch me in the stomach, I'm out for the count, right? And you and Lorraine live happily ever after.

    this has gotta be a dream. No, fine, no , good, fine, good. Doc. Whoa, wait, Doc. Alright kid, you stick to your father like glue and make sure that he takes her to the dance.

    Yeah. Well, Biff. Well looky what we have here. No no no, you're staying right here with me. Don't pay any attention to him, he's in one of his moods. Sam, quit fiddling with that thing, come in here to dinner. Now let's see, you already know Lorraine, this is Milton, this is Sally, that's Toby, and over there in the playpen is little baby Joey. Yeah, I guessed you're a sailor, aren't you, that's why you wear that life preserver.

    Thanks a lot, kid. That's true, Marty, I think you should spend the night. I think you're our responsibility. C'mon, c'mon let's go. Let me show you my plan for sending you home. Please excuse the crudity of this model, I didn't have time to build it to scale or to paint it. Y'know this time it wasn't my fault. The Doc set all of his clocks twenty-five minutes slow.

    Look, you gotta listen to me. It's about the future, isn't it? Remember, fellas, the future is in your hands. If you believe in progress, re-elect Mayor Red Thomas, progress is his middle name. Mayor Red Thomas's progress platform means more jobs, better education, bigger civic improvements, and lower taxes. On election day, cast your vote for a proven leader, re-elect Mayor Red Thomas... Bet your ass it works. The hell you doing to my car?

    We do now. A block passed Maple, that's John F. Kennedy Drive. Doc. Where the hell are they. Marty, this may seem a little foreward, but I was wondering if you would ask me to the Enchantment Under The Sea Dance on Saturday.

    Hello, Jennifer. Hey kid, what you do, jump ship? Whoa, they really cleaned this place up, looks brand new. Uncle Jailbird Joey? Thank god I still got my hair. What on Earth is that thing I'm wearing?

    Doc. That's Strickland. Jesus, didn't that guy ever have hair? What a nightmare. Well, they're your parents, you must know them. What are their common interests, what do they like to do together? Now remember, according to my theory you interfered with with your parent's first meeting. They don't meet, they don't fall in love, they won't get married and they wont have kids. That's why your older brother's disappeared from that photograph. Your sister will follow and unless you repair the damages, you will be next.

    Oh. Uh, look me up when you get there. Listen, I gotta go but I wanted to tell you that it's been educational. My equipment, that reminds me, Marty, you better not hook up to the amplifier. There's a slight possibility for overload. Thanks.

    Oh, you make it sound so easy. I just, I wish I wasn't so scared. Hey beat it, spook, this don't concern you. 1955? You're my ma- you're my ma. Jennifer, oh are you a sight for sore eyes. Let me look at you. Say, why do you let those boys push you around like that?

    Of course, from a group of Libyan Nationalists. They wanted me to build them a bomb, so I took their plutonium and in turn gave them a shiny bomb case full of used pinball machine parts. C'mon, c'mon let's go. No no no this sucker's electrical, but I need a nuclear reaction to generate the one point twenty-one gigawatts of electricity that I need. You don't understand. Now that's a risk you'll have to take you're life depends on it.

    Say, why do you let those boys push you around like that? That Biff, what a character. Always trying to get away with something. Been on top of Biff ever since high school. Although, if it wasn't for him- Uncle Jailbird Joey? When could weathermen predict the weather, let alone the future. Right.

    My equipment, that reminds me, Marty, you better not hook up to the amplifier. There's a slight possibility for overload. No, Marty, we've already agreed that having information about the future could be extremely dangerous. Even if your intentions are good, they could backfire drastically. Whatever you've got to tell me I'll find out through the natural course of time. Oh. Hey beat it, spook, this don't concern you. Hey, hey listen guys. Look, I don't wanna mess with no reefer addicts, okay?

    Well, ma, we talked about this, we're not gonna go to the lake, the car's wrecked. Let's get you into a radiation suit, we must prepare to reload. Yeah, alright, bye-bye. What? Uh, Doc. What did you sleep in your clothes again last night.

    Ah, where're my pants? You too. This is for all you lovers out there. Stop it. What did you say?

    I still don't understand, how am I supposed to go to the dance with her, if she's already going to the dance with you. Watch it, Goldie. I'll call you tonight. He's your brother, Mom. Yes, definitely, god-dammit George, swear. Okay, so now, you come up, you punch me in the stomach, I'm out for the count, right? And you and Lorraine live happily ever after.

    Our first television set, Dad just picked it up today. Do you have a television? Good, I'll see you tonight. Don't forget, now, 1:15 a.m., Twin Pines Mall. Right check, Doc. Ho ho ho, look at it roll. Now we could watch Jackie Gleason while we eat. What, well you mean like a date?

    The future, it's where you're going? He's absolutely right, Marty. the last thing you need is headaches. Listen, I gotta go but I wanted to tell you that it's been educational. That's a Florence Nightingale effect. It happens in hospitals when nurses fall in love with their patients. Go to it, kid. Are you okay?

    We never would have fallen in love. Which one's your pop? Oh, thank you, thank you. Okay now, we run some industrial strength electrical cable from the top of the clocktower down to spreading it over the street between two lamp posts. Meanwhile, we out-fitted the vehicle with this big pole and hook which runs directly into the flux-capacitor. At the calculated moment, you start off from down the street driving toward the cable execrating to eighty-eight miles per hour. According to the flyer, at !0:04 pm lightning will strike the clocktower sending one point twenty-one gigawatts into the flux-capacitor, sending you back to 1985. Alright now, watch this. You wind up the car and release it, I'll simulate the lightening. Ready, set, release. Huhh. I'm sure that in 1985, plutonium is available at every corner drug store, but in 1955, it's a little hard to come by. Marty, I'm sorry, but I'm afraid you're stuck here. Well, ma, we talked about this, we're not gonna go to the lake, the car's wrecked.

    You bet. Mom, is that you? Time machine, I haven't invented any time machine. Wait a minute, wait a minute, Doc, are you telling me that you built a time machine out of a delorean. Remember, fellas, the future is in your hands. If you believe in progress, re-elect Mayor Red Thomas, progress is his middle name. Mayor Red Thomas's progress platform means more jobs, better education, bigger civic improvements, and lower taxes. On election day, cast your vote for a proven leader, re-elect Mayor Red Thomas...

    Actually, people call me Marty. Mother, with Marty's parents out of town, don't you think he oughta spend the night, after all, Dad almost killed him with the car. whoa, this is it, this is the part coming up, Doc. Let's get you into a radiation suit, we must prepare to reload. Which one's your pop?

    Just relax now Calvin, you've got a big bruise on you're head. Now, now, Biff, now, I never noticed any blindspot before when I would drive it. Hi, son. You got a permit for that? Our first television set, Dad just picked it up today. Do you have a television? Marty, I'm sorry, but the only power source capable of generating one point twenty-one gigawatts of electricity is a bolt of lightning.

    C'mon. He's a peeping tom. Dad. Don't pay any attention to him, he's in one of his moods. Sam, quit fiddling with that thing, come in here to dinner. Now let's see, you already know Lorraine, this is Milton, this is Sally, that's Toby, and over there in the playpen is little baby Joey. Yeah man, that was good. Let's do another one. Well, Marty, I want to thank you for all your good advice, I'll never forget it.

    Hey man, the dance is over. Unless you know someone else who could play the guitar. Lorenzo, where're you keys? You broke it. Wow, look at him go. Leave me alone. Alright, okay. Alright, there she is, George. Just go in there and invite her.

    I noticed you band is on the roster for dance auditions after school today. Why even bother Mcfly, you haven't got a chance, you're too much like your own man. No McFly ever amounted to anything in the history of Hill Valley. George, help me, please. Yeah man, that was good. Let's do another one. Just finishing up the second coat now. You can't, uh, that is, uh, nobody's home.

    Go. Wait a minute, Doc. What are you talking about? What happens to us in the future? What do we become assholes or something? I need fuel. Go ahead, quick, get in the car. Why is she gonna get angry with you? The car, Dad, I mean He wrecked it, totaled it. I needed that car tomorrow night, Dad, I mean do you have any idea how important this was, do you have any clue?

    George, there's nothing to be scared of. All it takes is a little self confidence. You know, if you put your mind to it, you could accomplish anything. But I can't go to the dance, I'll miss my favorite television program, Science Fiction Theater. Uh, no, no, no, no. What are you looking at, butt-head? Can't be. This is nuts. Aw, c'mon. Thank god I still got my hair. What on Earth is that thing I'm wearing?

    You know what I do in those situations? Well, what if they didn't like them, what if they told me I was no good. I guess that would be pretty hard for somebody to understand. No, fine, no , good, fine, good. Precisely. Hey, Doc? Doc. Hello, anybody home? Einstein, come here, boy. What's going on? Wha- aw, god. Aw, Jesus. Whoa, rock and roll. Yo

    Hey, George, buddy, you weren't at school, what have you been doing all day? What did your mother ever see in that kid? He's fine, and he's completely unaware that anything happened. As far as he's concerned the trip was instantaneous. That's why Einstein's watch is exactly one minute behind mine. He skipped over that minute to instantly arrive at this moment in time. Come here, I'll show you how it works. First, you turn the time circuits on. This readout tell you where you're going, this one tells you where you are, this one tells you where you were. You imput the destination time on this keypad. Say, you wanna see the signing of the declaration of independence, or witness the birth or Christ. Here's a red-letter date in the history of science, November 5, 1955. Yes, of course, November 5, 1955. I don't wanna see you in here again. You'll find out in thirty years.

    Oh. Yeah, you got my homework finished, McFly? Well, she's not doing a very good job. Hey. Why am I always the last one to know about these things.

    No sir, I'm gonna make something out of myself, I'm going to night school and one day I'm gonna be somebody. Let me show you my plan for sending you home. Please excuse the crudity of this model, I didn't have time to build it to scale or to paint it. Doc. That's right. Biff.

    Scram, McFly. whoa, whoa Doc, stuck here, I can't be stuck here, I got a life in 1985. I got a girl. That's a Florence Nightingale effect. It happens in hospitals when nurses fall in love with their patients. Go to it, kid. Marty, why are you so nervous? Well, this is a radiation suit.

    I can't believe you loaned me a car, without telling me it had a blindspot. I could've been killed. Can I go now, Mr. Strickland? Marty, will we ever see you again? Uh, well, I gotta go. I know, and all I could say is I'm sorry.

    Pa, what is it? What is it, Pa? Your not gonna be picking a fight, Dad, dad dad daddy-o. You're coming to a rescue, right? Okay, let's go over the plan again. 8:55, where are you gonna be. Let's get you into a radiation suit, we must prepare to reload. Believe me, Marty, you're better off not having to worry about all the aggravation and headaches of playing at that dance. Ah.

    Mr. McFly, Mr. McFly, this just arrived, oh hi Marty. I think it's your new book. That's a Florence Nightingale effect. It happens in hospitals when nurses fall in love with their patients. Go to it, kid. That's right, he's gonna be mayor. Great Scott. Let me see that photograph again of your brother. Just as I thought, this proves my theory, look at your brother. What?

    Nothing. Because, you might regret it later in life. What, what is it hot? Oh, no no no, I never uh, I never let anybody read my stories. C'mon, c'mon.

    That's right. Wait a minute, what are you doing, Doc? Now, now, Biff, now, I never noticed any blindspot before when I would drive it. Hi, son. Marty, don't be such a square. Everybody who's anybody drinks. I swiped it from the old lady's liquor cabinet.

    Radiation suit, of course, cause all of the fall out from the atomic wars. This is truly amazing, a portable television studio. No wonder your president has to be an actor, he's gotta look good on television. Wait a minute. Wait a minute, Doc. Are you telling me that it's 8:25? Working. Ah. Whoa. Well, Marty, I'm almost eighteen-years-old, it's not like I've never parked before.

    You know, Doc, you left your equipment on all week. Hey, hey, I've seen this one, I've seen this one. This is a classic, this is where Ralph dresses up as the man from space. Who? Hey I'm talking to you, McFly, you Irish bug. He laid out Biff in one punch. I never knew he had it in him. He never stood up to Biff in his life.

    I don't like her, Marty. Any girl who calls a boy is just asking for trouble. Watch it, Goldie. Let's go. Yeah, he's right here. Let's get him.

    I'd like you to meet my good friend George McFly. No, I refuse to except the responsibility. Oh, great scott. You get the cable, I'll throw the rope down to you. Hi. I swiped it from the old lady's liquor cabinet.

    The car, Dad, I mean He wrecked it, totaled it. I needed that car tomorrow night, Dad, I mean do you have any idea how important this was, do you have any clue? And Jack Benny is secretary of the Treasury. Well, aren't you going up to the lake tonight, you've been planning it for two weeks. Good. Have a good trip Einstein, watch your head. My name's Lorraine, Lorraine Baines.

    This sounds pretty heavy. Well that's your name, isn't it? Calvin Klein. it's written all over your underwear. Oh, I guess they call you Cal, huh? Quiet. 1955? You're my ma- you're my ma. Well, this is a radiation suit.

    Marty, this may seem a little foreward, but I was wondering if you would ask me to the Enchantment Under The Sea Dance on Saturday. I can't play. Yeah, yeah what are you wearing, Dave. C'mon, he's not that bad. At least he's letting you borrow the car tomorrow night. Wow, ah Red, you look great. Everything looks great. 1:24, I still got time. Oh my god. No, no not again, c'mon, c'mon. Hey. Libyans.

    No, Marty, we've already agreed that having information about the future could be extremely dangerous. Even if your intentions are good, they could backfire drastically. Whatever you've got to tell me I'll find out through the natural course of time. Ah. Whoa. David, watch your mouth. You come here and kiss your mother before you go, come here. oh yeah, all you gotta do is go over there and ask her. Unfortunately no, it requires something with a little more kick, plutonium.

    No, Doc. Stop it. Okay, but I don't know what to say. I don't like her, Marty. Any girl who calls a boy is just asking for trouble. Quiet down, I'm sure the car is fine.

    Uh, stories, science fiction stories, about visitors coming down to Earth from another planet. I'm writing this down, this is good stuff. Go. That was the day I invented time travel. I remember it vividly. I was standing on the edge of my toilet hanging a clock, the porces was wet, I slipped, hit my head on the edge of the sink. And when I came to I had a revelation, a picture, a picture in my head, a picture of this. This is what makes time travel possible. The flux capacitor. Did you hurt your head?

    Wait a minute, Doc. What are you talking about? What happens to us in the future? What do we become assholes or something? Oh, yeah, yeah. whoa, this is it, this is the part coming up, Doc. He's alright. Welcome to my latest experiment. It's the one I've been waiting for all my life.

    Well, because George, nice girls get angry when guys take advantage of them. Doc, is that a de- You bet. No sir, I'm gonna make something out of myself, I'm going to night school and one day I'm gonna be somebody. Quiet, quiet. I'm gonna read your thoughts. Let's see now, you've come from a great distance?

    Wrecked? When did this happen and- Take care. I haven't Don't worry. As long as you hit that wire with the connecting hook at precisely 88 miles per hour, the instance the lightning strikes the tower, everything will be fine. Never mind that, never mind that now, never mind that, never mind-

    My god, it's my mother. Put your pants back on. I don't wanna know your name. I don't wanna know anything anything about you. Doc, is that a de- Great Scott. Let me see that photograph again of your brother. Just as I thought, this proves my theory, look at your brother. Alright, let's set your destination time. This is the exact time you left. I'm gonna send you back at exactly the same time. It's be like you never left. Now, I painted a white line on the street way over there, that's where you start from. I've calculated the distance and wind resistance fresh to active from the moment the lightning strikes, at exactly 7 minutes and 22 seconds. When this alarm goes off you hit the gas.

    My insurance, it's your car, your insurance should pay for it. Hey, I wanna know who's gonna pay for this? I spilled beer all over it when that car smashed into me. Who's gonna pay my cleaning bill? Marty you gotta come back with me. Uh, no, no, no, no. What are you looking at, butt-head? Right. Lou, gimme a milk, chocolate. Lorraine, my density has popped me to you. Ronald Reagon.

    I think we need a rematch. No, bastards. Leave her alone, you bastard. Marty, is that you? Hey George, heard you laid out Biff, nice going.

    Oh, I've been so worried about you ever since you ran off the other night. Are you okay? I'm sorry I have to go. Isn't he a dream boat? Quiet, quiet. I'm gonna read your thoughts. Let's see now, you've come from a great distance? Yes, definitely, god-dammit George, swear. Okay, so now, you come up, you punch me in the stomach, I'm out for the count, right? And you and Lorraine live happily ever after. Alright, alright, okay McFly, get a grip on yourself. It's all a dream. Just a very intense dream. Woh, hey, listen, you gotta help me. Yeah well look, Marvin, Marvin, you gotta play. See that's where they kiss for the first time on the dance floor. And if there's no music, they can't dance, and if they can't dance, they can't kiss, and if they can't kiss, they can't fall in love and I'm history.

    What, what? But, what are you blind McFly, it's there. How else do you explain that wreck out there? Back to the future. What? Marty, you interacted with anybody else today, besides me?

    Right, okay, so right around 9:00 she's gonna get very angry with me. Right, and where am I gonna be? Well, I figured, what the hell. Evening, Doctor Brown, what's with the wire? Wow, you must be rich.

    Marty, that was very interesting music. Right. What? Where the hell are they. Children.

    Next, please. Mayor Goldie Wilson, I like the sound of that. Right. Working. Yeah, well, how about my homework, McFly?

    Excuse me. No. C'mon, open up, let me out of here, Yo. Wrecked? George, help me, please.

    Are those my clocks I hear? Get your meat hooks off of me. C'mon, more, dammit. Jeez. Holy shit. Let's see if you bastards can do ninety. whoa, whoa Doc, stuck here, I can't be stuck here, I got a life in 1985. I got a girl. Well gee, I don't know.

    Now, now, Biff, now, I never noticed any blindspot before when I would drive it. Hi, son. C'mon, he's not that bad. At least he's letting you borrow the car tomorrow night. I just wanna use the phone. C'mon, he's not that bad. At least he's letting you borrow the car tomorrow night. Dear Doctor Brown, on the night that I go back in time, you will be shot by terrorists. Please take whatever precautions are necessary to prevent this terrible disaster. Your friend, Marty.

    Hello, Jennifer. Save the clock tower. Ronald Reagon. Uh no, not hard at all. So anyway, George, now Lorraine, she really likes you. She told me to tell you that she wants you to ask her to the Enchantment Under The Sea Dance. A block passed Maple, that's John F. Kennedy Drive.

    Hey, hey, Doc, where are you? How could I have been so careless. One point twenty-one gigawatts. Tom, how am I gonna generate that kind of power, it can't be done, it can't. It was meant to be. Anyway, if Grandpa hadn't hit him, then none of you would have been born. Listen, woh. Hello, uh excuse me. Sorry about your barn. Chuck, Chuck, its' your cousin. Your cousin Marvin Berry, you know that new sound you're lookin for, well listen to this.

    Erased from existence. Well uh, good, fine. No, fine, no , good, fine, good. I have to tell you about the future. Marty, that was very interesting music.

    Oh, just a little weather experiment. Well, safe and sound, now, n good old 1955. Yeah Mom, we know, you've told us this story a million times. You felt sorry for him so you decided to go with him to The Fish Under The Sea Dance. Uh, plutonium, wait a minute, are you telling me that this sucker's nuclear? Where's Einstein, is he with you?

    Ho, you mean you're gonna touch her on her- Listen, this is very important, I forgot my video camera, could you stop by my place and pick it up on your way to the mall? What, right here right now in the cafeteria? What if she said no? I don't know if I could take that kind of rejection. Besides, I think she'd rather go with somebody else. That's true, Marty, I think you should spend the night. I think you're our responsibility. Why that's me, look at me, I'm an old man.

    Right, I got it. Jennifer. Doc, she didn't even look at him. Quiet down, I'm sure the car is fine. Lorenzo, where're you keys?

    Please note that Einstein's clock is in complete synchronization with my control watch. I followed you. Um, yeah well I might have sort of ran into my parents. Ohh, no. So what's it to you, butthead. You know you've been looking for a, since you're new here, I'm gonna cut you a break, today. So why don't you make like a tree, and get out of here.

    oh yeah, all you gotta do is go over there and ask her. Listen, woh. Hello, uh excuse me. Sorry about your barn. Well, uh, listen, uh, I really- That's George McFly? Well, what if they didn't like them, what if they told me I was no good. I guess that would be pretty hard for somebody to understand.

    We're gonna take a little break but we'll be back in a while so, don't nobody go no where. Yeah, it's 8:00. Look at the time, you've got less than 4 minutes, please hurry. Doc, is that a de- Hey c'mon, I had to change, you think I'm going back in that zoot suit? The old man really came through it worked.

    Mother, with Marty's parents out of town, don't you think he oughta spend the night, after all, Dad almost killed him with the car. Marty, why are you so nervous? That's a great idea. I'd love to park. Look, I'm just not ready to ask Lorraine out to the dance, and not you, nor anybody else on this planet is gonna make me change my mind. Alright, c'mon, I think we're safe.

    Without any sugar. Doc. Well, they're bigger than me. This Saturday night, mostly clear, with some scattered clouds. Lows in the upper forties. Brown, Brown, Brown, Brown, Brown, great, you're alive. Do you know where 1640 Riverside-

    What's with the life preserver? Yeah, you got my homework finished, McFly? Indeed I will, roll em. I, Doctor Emmett Brown, am about to embark on an historic journey. What have I been thinking of, I almost forgot to bring some extra plutonium. How did I ever expect to get back, one pallet one trip I must be out of my mind. What is it Einy? Oh my god, they found me, I don't know how but they found me. Run for it, Marty. George McFly? Oh, he's kinda cute and all, but, well, I think a man should be strong, so he could stand up for himself, and protect the woman he loves. Don't you? Good evening, I'm Doctor Emmet Brown, I'm standing here on the parking lot of-

    Alright, okay. Alright, there she is, George. Just go in there and invite her. Let's go. It's uh, the other end of town, a block past Maple. Uh, well, okay Biff, uh, I'll finish that on up tonight and I'll bring it over first thing tomorrow morning. No no no no no, Marty, both you and Jennifer turn out fine. It's your kids, Marty, something has got to be done about your kids.

    Wait a minute, wait a minute, Doc, are you telling me that you built a time machine out of a delorean. Why not? Never mind that now, never mind that now. Yeah, I'll keep that in mind. Who?

    Really. Well maybe you are and you just don't know it yet. You want it, you know you want it, and you know you want me to give it to you. Biff. In that case, I'll tell you strait out.

    Don't tell me. Uh, you want me to buy a subscription to the Saturday Evening Post? Say that again. That's Calvin Klein, oh my god, he's a dream. I think it's terrible. Girls chasing boys. When I was your age I never chased a boy, or called a boy, or sat in a parked car with a boy. Hello, hello, anybody home? Think, McFly, think. I gotta have time to recopy it. Do your realize what would happen if I hand in my homework in your handwriting? I'd get kicked out of school. You wouldn't want that to happen would you, would you?

    Okay. He's your brother, Mom. Uh, stories, science fiction stories, about visitors coming down to Earth from another planet. Y'know this time it wasn't my fault. The Doc set all of his clocks twenty-five minutes slow. Oh hey, Biff, hey, guys, how are you doing?

    Well just gimme something without any sugar in it, okay? Alright kid, you stick to your father like glue and make sure that he takes her to the dance. Right, I got it. Calvin, why do you keep calling me Calvin? The car, Dad, I mean He wrecked it, totaled it. I needed that car tomorrow night, Dad, I mean do you have any idea how important this was, do you have any clue?

    This is for all you lovers out there. My god, do you know what this means? It means that this damn thing doesn't work at all. Whoa, this is heavy. Don't worry. As long as you hit that wire with the connecting hook at precisely 88 miles per hour, the instance the lightning strikes the tower, everything will be fine. C'mon, open up, let me out of here, Yo.

    I gotta go, uh, I gotta go. Thanks very much, it was wonderful, you were all great. See you all later, much later. Doc, Doc. Oh, no. You're alive. Bullet proof vest, how did you know, I never got a chance to tell you. About all that talk about screwing up future events, the space time continuum. You do? What the hell is a gigawatt? Whoa, whoa, okay.

    What? You cost three-hundred buck damage to my car, you son-of-a-bitch. And I'm gonna take it out of your ass. Hold him. It's information about the future isn't it. I warned you about this kid. The consequences could be disastrous. Don't tell me. Uh, you want me to buy a subscription to the Saturday Evening Post? I'm writing this down, this is good stuff.

    Marty, will we ever see you again? Yeah, well history is gonna change. Uh, yeah. You bet. Huh?

    Yeah, I think it's a major embarrassment having an uncle in prison. Believe me, Marty, you're better off not having to worry about all the aggravation and headaches of playing at that dance. Breakfast. Well just gimme something without any sugar in it, okay? Wait a minute, wait a minute, Doc, are you telling me that you built a time machine out of a delorean.

    Don't say a word. No no no, Doc, I just got here, okay, Jennifer's here, we're gonna take the new truck for a spin. Breakfast. Well, I figured, what the hell. What's the meaning of this.

    Let me show you my plan for sending you home. Please excuse the crudity of this model, I didn't have time to build it to scale or to paint it. You extol me with a lot of confidence, Doc. I'm sure that in 1985, plutonium is available at every corner drug store, but in 1955, it's a little hard to come by. Marty, I'm sorry, but I'm afraid you're stuck here. Well looky what we have here. No no no, you're staying right here with me. Time machine, I haven't invented any time machine.

    Yeah well look, Marvin, Marvin, you gotta play. See that's where they kiss for the first time on the dance floor. And if there's no music, they can't dance, and if they can't dance, they can't kiss, and if they can't kiss, they can't fall in love and I'm history. Marty you gotta come back with me. Back to the future. Well, what if they didn't like them, what if they told me I was no good. I guess that would be pretty hard for somebody to understand. I still don't understand, how am I supposed to go to the dance with her, if she's already going to the dance with you.

    I guarantee it. Well, they're bigger than me. I have to tell you about the future. The hell you doing to my car? Yeah, sure, okay.

    Alright, okay listen, keep your pants on, she's over in the cafe. God, how do you do this? What made you change your mind, George? Whoa, they really cleaned this place up, looks brand new. He's a very strange young man. What, what? You bet.

    No wait, Doc, the bruise, the bruise on your head, I know how that happened, you told me the whole story. you were standing on your toilet and you were hanging a clock, and you fell, and you hit your head on the sink, and that's when you came up with the idea for the flux capacitor, which makes time travel possible. Will you take care of that? Let's put him in there. Right, I got it. See, there's Biff out there waxing it right now. Now, Biff, I wanna make sure that we get two coats of wax this time, not just one.

    Hey wait, wait a minute, who are you? Stella, another one of these damn kids jumped in front of my car. Come on out here, help me take him in the house. I have to tell you about the future. Pretty Mediocre photographic fakery, they cut off your brother's hair. Well, I figured, what the hell. We never would have fallen in love.

    What the hell is this? Wow, ah Red, you look great. Everything looks great. 1:24, I still got time. Oh my god. No, no not again, c'mon, c'mon. Hey. Libyans. Who are you calling spook, pecker-wood. But, what are you blind McFly, it's there. How else do you explain that wreck out there? I'm gonna be at the dance.

    Ah, honey, your first novel. Something wrong with the starter, so I hid it. It's a board with wheels. What did you say? Mom, Dad.

    Well, safe and sound, now, n good old 1955. Like I always told you, if you put your mind to it you could accomplish anything. Thank god I still got my hair. What on Earth is that thing I'm wearing? What? Don't worry. As long as you hit that wire with the connecting hook at precisely 88 miles per hour, the instance the lightning strikes the tower, everything will be fine.

    Jennifer, oh are you a sight for sore eyes. Let me look at you. Um, yeah, I'm on my way. Yeah well look, Marvin, Marvin, you gotta play. See that's where they kiss for the first time on the dance floor. And if there's no music, they can't dance, and if they can't dance, they can't kiss, and if they can't kiss, they can't fall in love and I'm history. Let's get you into a radiation suit, we must prepare to reload. George. George.

    Leave me alone. Yeah, yeah what are you wearing, Dave. I think you got the wrong car, McFly. You got a real attitude problem, McFly. You're a slacker. You remind me of you father when he went her, he was a slacker too. Yeah, I'll keep that in mind.

    I know, and all I could say is I'm sorry. No no no no no, Marty, both you and Jennifer turn out fine. It's your kids, Marty, something has got to be done about your kids. Shit. Alright, punk, now- Well, safe and sound, now, n good old 1955.

    No sir, I'm gonna make something out of myself, I'm going to night school and one day I'm gonna be somebody. Marty, that's completely out of the question, you must not leave this house. you must not see anybody or talk to anybody. Anything you do could have serious repercussions on future events. Do you understand? Of course not, Biff, now I wouldn't want that to happen. Now, uh, I'll finish those reports up tonight, and I'll run em them on over first thing tomorrow, alright? I swiped it from the old lady's liquor cabinet. My god, do you know what this means? It means that this damn thing doesn't work at all.

    Wrecked? Just relax now Calvin, you've got a big bruise on you're head. Wait a minute, wait a minute, Doc, are you telling me that you built a time machine out of a delorean. My insurance, it's your car, your insurance should pay for it. Hey, I wanna know who's gonna pay for this? I spilled beer all over it when that car smashed into me. Who's gonna pay my cleaning bill? Doc, Doc, it's me, Marty.

    Right. Over there, on my hope chest. I've never seen purple underwear before, Calvin. I'm gonna get that son-of-a-bitch. George, aren't you gonna kiss me? What did you say?

    Yeah. Just say anything, George, say what ever's natural, the first thing that comes to your mind. No, it was The Enchantment Under The Sea Dance. Our first date. It was the night of that terrible thunderstorm, remember George? Your father kissed me for the very first time on that dance floor. It was then I realized I was going to spend the rest of my life with him. Doc? I have a feeling too.

    I guess you guys aren't ready for that yet. But your kids are gonna love it. C'mon, Mom, make it fast, I'll miss my bus. Hey see you tonight, Pop. Woo, time to change that oil. It's my dad. Oh. Mr. McFly, Mr. McFly, this just arrived, oh hi Marty. I think it's your new book.

    Dammit, Doc, why did you have to tear up that letter? If only I had more time. Wait a minute, I got all the time I want I got a time machine, I'll just go back and warn him. 10 minutes oughta do it. Time-circuits on, flux-capacitor fluxing, engine running, alright. No, no no no no, c'mon c'mon. C'mon c'mon, here we go, this time. Please, please, c'mon. Who's are these? Right, George. Well, good luck you guys. Oh, one other thing, if you guys ever have kids and one of them when he's eight years old, accidentally sets fire to the living room rug, be easy on him. Yeah man, that was good. Let's do another one. Hey not too early I sleep in Sunday's, hey McFly, you're shoe's untied, don't be so gullible, McFly.

    Where does he come from? Who? Oh, uh, this is my Doc, Uncle, Brown. Never? Calvin, why do you keep calling me Calvin?

    Evening, Doctor Brown, what's with the wire? Okay. Hey not too early I sleep in Sunday's, hey McFly, you're shoe's untied, don't be so gullible, McFly. It's about the future, isn't it? Just finishing up the second coat now.

    Your not gonna be picking a fight, Dad, dad dad daddy-o. You're coming to a rescue, right? Okay, let's go over the plan again. 8:55, where are you gonna be. So tell me, Marty, how long have you been in port? Why do you keep following me around? That's Calvin Klein, oh my god, he's a dream. My name's Lorraine, Lorraine Baines.

    No no no no no, Marty, both you and Jennifer turn out fine. It's your kids, Marty, something has got to be done about your kids. Where were we. Marty, you made it. Great good, good, Lorraine, I had a feeling about you two. Nothing's coming to my mind.

    Hey George, heard you laid out Biff, nice going. Marty, you interacted with anybody else today, besides me? Dammit, Doc, why did you have to tear up that letter? If only I had more time. Wait a minute, I got all the time I want I got a time machine, I'll just go back and warn him. 10 minutes oughta do it. Time-circuits on, flux-capacitor fluxing, engine running, alright. No, no no no no, c'mon c'mon. C'mon c'mon, here we go, this time. Please, please, c'mon. Why not? Yeah, gimme a Tab.

    What's that thing he's on? Huh? Wait a minute, wait a minute, Doc, are you telling me that you built a time machine out of a delorean. It's taken me almost thirty years and my entire family fortune to realize the vision of that day, my god has it been that long. Things have certainly changed around here. I remember when this was all farmland as far as the eye could see. Old man Peabody, owned all of this. He had this crazy idea about breeding pine trees. Oh, yeah, yeah.

    Just say anything, George, say what ever's natural, the first thing that comes to your mind. Marty, this may seem a little foreward, but I was wondering if you would ask me to the Enchantment Under The Sea Dance on Saturday. We're gonna take a little break but we'll be back in a while so, don't nobody go no where. Excuse me. One point twenty-one gigawatts. One point twenty-one gigawatts. Great Scott.

    I'm, I'm sorry, Mr. McFly, I mean, I was just starting on the second coat. He's your brother, Mom. Right. Uh, Lorraine. How did you know I was here? That's a big bruise you have there.

    Hey beat it, spook, this don't concern you. I know, and all I could say is I'm sorry. I followed you. Really. You want it, you know you want it, and you know you want me to give it to you.

    Uh, yeah. That's Calvin Klein, oh my god, he's a dream. What you got under here? Hey wait, wait a minute, who are you? Stella, another one of these damn kids jumped in front of my car. Come on out here, help me take him in the house. No no no this sucker's electrical, but I need a nuclear reaction to generate the one point twenty-one gigawatts of electricity that I need.

    Huh? We never would have fallen in love. Well, Biff. I don't know, Doc, I guess she felt sorry for him cause her did hit him with the car, hit me with the car. Bet your ass it works.

    Okay, real mature guys. Okay, Biff, will you pick up my books? Wow, you must be rich. Uh, I think so. It was meant to be. Anyway, if Grandpa hadn't hit him, then none of you would have been born. I know, and all I could say is I'm sorry.

    Don't worry, I'll take care of the lightning, you take care of your pop. By the way, what happened today, did he ask her out? Well, uh, listen, uh, I really- It's safe now. Everything's lead lined. Don't you lose those tapes now, we'll need a record. Wup, wup, I almost forgot my luggage. Who knows if they've got cotton underwear in the future. I'm allergic to all synthetics. Well, bring her along. This concerns her too. Oh hey, Biff, hey, guys, how are you doing?

    We're gonna take a little break but we'll be back in a while so, don't nobody go no where. Who are you calling spook, pecker-wood. No, it was The Enchantment Under The Sea Dance. Our first date. It was the night of that terrible thunderstorm, remember George? Your father kissed me for the very first time on that dance floor. It was then I realized I was going to spend the rest of my life with him. No no no this sucker's electrical, but I need a nuclear reaction to generate the one point twenty-one gigawatts of electricity that I need. Watch it, Goldie.

    Now, now, Biff, now, I never noticed any blindspot before when I would drive it. Hi, son. Whoa, wait a minute, Doc, are you telling me that my mother has got the hots for me? Mr. McFly, Mr. McFly, this just arrived, oh hi Marty. I think it's your new book. I know, and all I could say is I'm sorry. Oh, if Paul calls me tell him I'm working at the boutique late tonight.

    C'mon. I guess you guys aren't ready for that yet. But your kids are gonna love it. You heard her she said get your meat hooks, off, uh please. Wrecked? When did this happen and- Hello.

    George, help me, please. whoa, this is it, this is the part coming up, Doc. Well, it will just happen. Like the way I met your father. Nothing, nothing, nothing, look tell her destiny has brought you together, tell her that she's the most beautiful you have ever seen. Girls like that stuff. What, what are you doing George? Wow, you must be rich.

    Keys? Hey, McFly, I thought I told you never to come in here. Well it's gonna cost you. How much money you got on you? Alright, good-bye Einy. Oh, watch that re-entry, it's a little bumpy. Uh, yeah. He's a very strange young man.

    Hello, hello, anybody home? Think, McFly, think. I gotta have time to get them re-typed. Do you realize what would happen if I hand in my reports in your handwriting. I'll get fired. You wouldn't want that to happen would you? Would you? You don't understand. Hey, don't I know you from somewhere? Yeah, well, I still don't understand what Dad was doing in the middle of the street. Uh, Doc.

    Not a word, not a word, not a word now. Quiet, uh, donations, you want me to make a donation to the coast guard youth auxiliary? Something that really cooks. Alright, alright this is an oldie, but uh, it's an oldie where I come from. Alright guys, let's do some blues riff in b, watch me for the changes, and uh, try and keep up, okay. Okay, alright, Saturday is good, Saturday's good, I could spend a week in 1955. I could hang out, you could show me around. After I fell off my toilet, I drew this. See, there's Biff out there waxing it right now. Now, Biff, I wanna make sure that we get two coats of wax this time, not just one.

    Why is she gonna get angry with you? Yeah but George, Lorraine wants to go with you. Give her a break. Marty, don't go this way. Strickland's looking for you. If you're caught it'll be four tardies in a row. Uh, Doc. Okay, that's enough. Now stop the microphone. I'm sorry fellas. I'm afraid you're just too darn loud. Next, please. Where's the next group, please.

    Now which one was it, Greg or Craig? Hi, Marty. Who's are these? Shape up, man. You're a slacker. You wanna be a slacker for the rest of your life? Now, Biff, um, can I assume that your insurance is gonna pay for the damage?

    Well, safe and sound, now, n good old 1955. George McFly? Oh, he's kinda cute and all, but, well, I think a man should be strong, so he could stand up for himself, and protect the woman he loves. Don't you? Wait a minute, what are you doing, Doc? Who do you think, the Libyans. Ohh, no.

    He's fine, and he's completely unaware that anything happened. As far as he's concerned the trip was instantaneous. That's why Einstein's watch is exactly one minute behind mine. He skipped over that minute to instantly arrive at this moment in time. Come here, I'll show you how it works. First, you turn the time circuits on. This readout tell you where you're going, this one tells you where you are, this one tells you where you were. You imput the destination time on this keypad. Say, you wanna see the signing of the declaration of independence, or witness the birth or Christ. Here's a red-letter date in the history of science, November 5, 1955. Yes, of course, November 5, 1955. Hey man, look at Marvin's hand. He can't play with his hands like that, and we can't play without him. Okay, okay you guys, oh ha ha ha very funny. Hey you guys are being real mature. What? Hey McFly, what do you think you're doing.

    Oh, oh a rematch, why, were you cheating? Y'know this time it wasn't my fault. The Doc set all of his clocks twenty-five minutes slow. I'm telling the truth, Doc, you gotta believe me. Sam, quit fiddling with that thing and come in here and eat your dinner. Uh, stories, science fiction stories, about visitors coming down to Earth from another planet.

    Oh. Yeah, but I never picked a fight in my entire life. Oh, I've been so worried about you ever since you ran off the other night. Are you okay? I'm sorry I have to go. Isn't he a dream boat? Right check, Doc. And he could sleep in my room.

    Well, Marty, I'm almost eighteen-years-old, it's not like I've never parked before. Right. Great Scott. Let me see that photograph again of your brother. Just as I thought, this proves my theory, look at your brother. Well, safe and sound, now, n good old 1955. Marty, you're acting like you haven't seen me in a week.

    One point twenty-one gigawatts. One point twenty-one gigawatts. Great Scott. C'mon. Yeah, it's in the back. Great good, good, Lorraine, I had a feeling about you two. Doc, look, all we need is a little plutonium.

    Wait a minute, Doc. What are you talking about? What happens to us in the future? What do we become assholes or something? How about a ride, Mister? Uh, no, no, no, no. What are you looking at, butt-head? It's my dad. He's a peeping tom. Dad.

    Just finishing up the second coat now. Yet. Check out that four by four. That is hot. Someday, Jennifer, someday. Wouldn't it be great to take that truck up to the lake. Throw a couple of sleeping bags in the back. Lie out under the stars. I'm sure that in 1985, plutonium is available at every corner drug store, but in 1955, it's a little hard to come by. Marty, I'm sorry, but I'm afraid you're stuck here. Let me show you my plan for sending you home. Please excuse the crudity of this model, I didn't have time to build it to scale or to paint it.

    Yeah, where does he live? He's an absolute dream. Leave her alone, you bastard. Right, gimme a Pepsi free. Flux capacitor.

    Uh, look me up when you get there. I have to tell you about the future. Hey, Doc? Doc. Hello, anybody home? Einstein, come here, boy. What's going on? Wha- aw, god. Aw, Jesus. Whoa, rock and roll. Yo I said the keys are in here. Pa, what is it? What is it, Pa?

    Will you take care of that? It's information about the future isn't it. I warned you about this kid. The consequences could be disastrous. I don't know, but I'm gonna find out. Hi, Marty. Is she pretty?

    Why am I always the last one to know about these things. What's that thing he's on? Ronald Reagon, the actor? Then who's vice president, Jerry Lewis? I suppose Jane Wymann is the first lady. C'mon, he's not that bad. At least he's letting you borrow the car tomorrow night. C'mon, Mom, make it fast, I'll miss my bus. Hey see you tonight, Pop. Woo, time to change that oil.

    Hey I'm talking to you, McFly, you Irish bug. Take care. Hello, hello, anybody home? Think, McFly, think. I gotta have time to recopy it. Do your realize what would happen if I hand in my homework in your handwriting? I'd get kicked out of school. You wouldn't want that to happen would you, would you? Oh, I've been so worried about you ever since you ran off the other night. Are you okay? I'm sorry I have to go. Isn't he a dream boat? Yeah, where does he live?

    That's a big bruise you have there. Uh? Oh, great scott. You get the cable, I'll throw the rope down to you. Good morning, Mom. Oh, Marty, I almost forgot, Jennifer Parker called. What the hell is a gigawatt?

    What do you mean you've seen this, it's brand new. What, what, ma? Never mind that now, never mind that now. Alright, okay listen, keep your pants on, she's over in the cafe. God, how do you do this? What made you change your mind, George? You're George McFly.

    Well, I figured, what the hell. I'm gonna get that son-of-a-bitch. About 30 years, it's a nice round number. Erased from existence. Well looky what we have here. No no no, you're staying right here with me.

    Yeah, I think maybe you do. Hey, Doc? Doc. Hello, anybody home? Einstein, come here, boy. What's going on? Wha- aw, god. Aw, Jesus. Whoa, rock and roll. Yo Um, yeah, I'm on my way. Precisely. Over there, on my hope chest. I've never seen purple underwear before, Calvin.

    That's Calvin Klein, oh my god, he's a dream. Right. Look, I'm just not ready to ask Lorraine out to the dance, and not you, nor anybody else on this planet is gonna make me change my mind. Doc, you gotta help- What a nightmare.

    Look, George, I'm telling you George, if you do not ask Lorraine to that dance, I'm gonna regret it for the rest of my life. Get out of town, I didn't know you did anything creative. Ah, let me read some. Whoa, whoa, kid, kid, stop, stop, stop, stop. You wanna a Pepsi, pall, you're gonna pay for it. We never would have fallen in love.

    Listen, I gotta go but I wanted to tell you that it's been educational. Perfect, just perfect. What's that thing he's on? I'm really gonna miss you. Doc, about the future- The way I see it, if you're gonna build a time machine into a car why not do it with some style. Besides, the stainless, steel construction made the flux dispersal- look out.

    Oh, uh, this is my Doc, Uncle, Brown. Oh yes sir. Wrecked? Never mind that now, never mind that now. Here you go, lady. There's a quarter.

    Doc. Indeed I will, roll em. I, Doctor Emmett Brown, am about to embark on an historic journey. What have I been thinking of, I almost forgot to bring some extra plutonium. How did I ever expect to get back, one pallet one trip I must be out of my mind. What is it Einy? Oh my god, they found me, I don't know how but they found me. Run for it, Marty. Hi. Uh? She's just trying to keep you respectable.

    C'mon, c'mon. The future, it's where you're going? Marty, don't go this way. Strickland's looking for you. If you're caught it'll be four tardies in a row. Yeah, but I never picked a fight in my entire life. It works, ha ha ha ha, it works. I finally invent something that works.

    Remember, fellas, the future is in your hands. If you believe in progress, re-elect Mayor Red Thomas, progress is his middle name. Mayor Red Thomas's progress platform means more jobs, better education, bigger civic improvements, and lower taxes. On election day, cast your vote for a proven leader, re-elect Mayor Red Thomas... Yeah okay. That was the day I invented time travel. I remember it vividly. I was standing on the edge of my toilet hanging a clock, the porces was wet, I slipped, hit my head on the edge of the sink. And when I came to I had a revelation, a picture, a picture in my head, a picture of this. This is what makes time travel possible. The flux capacitor. Well, ma, we talked about this, we're not gonna go to the lake, the car's wrecked. He's an absolute dream.

    He laid out Biff in one punch. I never knew he had it in him. He never stood up to Biff in his life. Are you gonna order something, kid? Well, Marty, I want to thank you for all your good advice, I'll never forget it. Listen, Doc, you know there's something I haven't told you about the night we made that tape. Yeah, I guessed you're a sailor, aren't you, that's why you wear that life preserver.

    Yeah but George, Lorraine wants to go with you. Give her a break. Right. Where? Good morning, Mom. Okay, that's enough. Now stop the microphone. I'm sorry fellas. I'm afraid you're just too darn loud. Next, please. Where's the next group, please.

    About how far ahead are you going? Hey guys, you gotta get back in there and finish the dance. No, I refuse to except the responsibility. Why that's me, look at me, I'm an old man. Bet your ass it works.

    Why that's me, look at me, I'm an old man. Well yeah, you know we have two of them. Does your mom know about tomorrow night? Oh, oh a rematch, why, were you cheating? You're George McFly.

    When could weathermen predict the weather, let alone the future. A block passed Maple, that's John F. Kennedy Drive. McFly. Yoo. Lorenzo, where're you keys?

    Hey Biff, check out this guy's life preserver, dork thinks he's gonna drown. Roads? Where we're going we don't need roads. Oh, what I meant to day was- Believe me, Marty, you're better off not having to worry about all the aggravation and headaches of playing at that dance. Yeah, but you're uh, you're so, you're so thin.

    You know what I do in those situations? There's that word again, heavy. Why are things so heavy in the future. Is there a problem with the Earth's gravitational pull? Oh, pleased to meet you, Calvin Marty Klein. Do you mind if I sit here? Sam, quit fiddling with that thing and come in here and eat your dinner. Bear with me, Marty, all of your questions will be answered. Roll tape, we'll proceed.

    Uh, Lorraine. How did you know I was here? Never? What, right here right now in the cafeteria? What if she said no? I don't know if I could take that kind of rejection. Besides, I think she'd rather go with somebody else. Doc, Doc. Oh, no. You're alive. Bullet proof vest, how did you know, I never got a chance to tell you. About all that talk about screwing up future events, the space time continuum. Thank god I still got my hair. What on Earth is that thing I'm wearing?

    I haven't I guarantee it. Yeah, sure, okay. You're gonna be in the car with her. Flux capacitor.

    Huh? I can't believe you loaned me a car, without telling me it had a blindspot. I could've been killed. Listen, this is very important, I forgot my video camera, could you stop by my place and pick it up on your way to the mall? Well, Marty, I'm almost eighteen-years-old, it's not like I've never parked before. A block passed Maple, that's John F. Kennedy Drive.

    What were you doing in the middle of the street, a kid your age. Right check, Doc. Um, well it's a delorean, right? The way I see it, if you're gonna build a time machine into a car why not do it with some style. Besides, the stainless, steel construction made the flux dispersal- look out. Right.

    The keys are in the trunk. Uh, coast guard. Who, who? Welcome to my latest experiment. It's the one I've been waiting for all my life. Listen, woh. Hello, uh excuse me. Sorry about your barn.

    Yes, yes, I'm George, George McFly, and I'm your density. I mean, I'm your destiny. George. You okay, is everything alright? I've gotta go. Well maybe you are and you just don't know it yet.

    Lorraine, have you ever, uh, been in a situation where you know you had to act a certain way but when you got there, you didn't know if you could go through with it? Well, aren't you going up to the lake tonight, you've been planning it for two weeks. No wait, Doc, the bruise, the bruise on your head, I know how that happened, you told me the whole story. you were standing on your toilet and you were hanging a clock, and you fell, and you hit your head on the sink, and that's when you came up with the idea for the flux capacitor, which makes time travel possible. Uh, Lorraine. How did you know I was here? Alright, McFly, you're asking for it, and now you're gonna get it.

    Hey man, look at Marvin's hand. He can't play with his hands like that, and we can't play without him. Breakfast. Thanks. Why do you keep following me around? Well, this is a radiation suit.

    My god, it's my mother. Put your pants back on. I think we need a rematch. What's the meaning of this. Well, ma, we talked about this, we're not gonna go to the lake, the car's wrecked. Yeah, who are you?

    Doc, look, all we need is a little plutonium. Where's Einstein, is he with you? You don't understand. Yeah, it's 8:00. Hey, not too early I sleep in on Saturday. Oh, McFly, your shoe's untied. Don't be so gullible, McFly. You got the place fixed up nice, McFly. I have you're car towed all the way to your house and all you've got for me is light beer. What are you looking at, butthead. Say hi to your mom for me.

    Calvin, why do you keep calling me Calvin? It's already mutated into human form, shoot it. In that case, I'll tell you strait out. Why that's me, look at me, I'm an old man. Ho, you mean you're gonna touch her on her-

    Jesus, George, it's a wonder I was ever born. Yeah, well uh, lets keep this brain melting stuff to ourselves, okay? Indeed I will, roll em. I, Doctor Emmett Brown, am about to embark on an historic journey. What have I been thinking of, I almost forgot to bring some extra plutonium. How did I ever expect to get back, one pallet one trip I must be out of my mind. What is it Einy? Oh my god, they found me, I don't know how but they found me. Run for it, Marty. The future, it's where you're going? C'mon man, let's do something that really cooks.

    What? What did you say? yes, Joey just loves being in his playpen. he cries whenever we take him out so we just leave him in there all the time. Well Marty, I hope you like meatloaf. Yeah well look, Marvin, Marvin, you gotta play. See that's where they kiss for the first time on the dance floor. And if there's no music, they can't dance, and if they can't dance, they can't kiss, and if they can't kiss, they can't fall in love and I'm history. Good evening, I'm Doctor Emmett Brown. I'm standing on the parking lot of Twin Pines Mall. It's Saturday morning, October 26, 1985, 1:18 a.m. and this is temporal experiment number one. C'mon, Einy, hey hey boy, get in there, that a boy, in you go, get down, that's it.

    This Saturday night, mostly clear, with some scattered clouds. Lows in the upper forties. I'm gonna ram him. What? Who do you think, the Libyans. Thank god I found you. Listen, can you meet me at Twin Pines Mall tonight at 1:15? I've made a major breakthrough, I'll need your assistance.

    Well, aren't you going up to the lake tonight, you've been planning it for two weeks. Jesus, you smoke too? Yeah. Oh, pleased to meet you, Calvin Marty Klein. Do you mind if I sit here? One point twenty-one gigawatts. One point twenty-one gigawatts. Great Scott.

    Oh, I've been so worried about you ever since you ran off the other night. Are you okay? I'm sorry I have to go. Isn't he a dream boat? Listen, Doc. C'mon, more, dammit. Jeez. Holy shit. Let's see if you bastards can do ninety. A colored mayor, that'll be the day. Are those my clocks I hear?

    Thank you, don't forget to take a flyer. Who the hell is John F. Kennedy? That's for messing up my hair. This sounds pretty heavy. Hey, Doc? Doc. Hello, anybody home? Einstein, come here, boy. What's going on? Wha- aw, god. Aw, Jesus. Whoa, rock and roll. Yo

    Right, George. Well, good luck you guys. Oh, one other thing, if you guys ever have kids and one of them when he's eight years old, accidentally sets fire to the living room rug, be easy on him. Yeah, I'm- mayor. Now that's a good idea. I could run for mayor. Alright, McFly, you're asking for it, and now you're gonna get it. What Lorraine, what? Something wrong with the starter, so I hid it.

    Where's Einstein, is he with you? Alright, okay Jennifer. What if I send in the tape and they don't like it. I mean, what if they say I'm no good. What if they say, 'Get out of here, kid, you got no future.' I mean, I just don't think I can take that kind of rejection. Jesus, I'm beginning to sound like my old man. Marty, that was very interesting music. When could weathermen predict the weather, let alone the future. That's true, Marty, I think you should spend the night. I think you're our responsibility.

    Ah, where're my pants? Ronald Reagon. I don't wanna know your name. I don't wanna know anything anything about you. Lorraine, have you ever, uh, been in a situation where you know you had to act a certain way but when you got there, you didn't know if you could go through with it? Oh, if Paul calls me tell him I'm working at the boutique late tonight.

    Yes, definitely, god-dammit George, swear. Okay, so now, you come up, you punch me in the stomach, I'm out for the count, right? And you and Lorraine live happily ever after. Oh, uh, this is my Doc, Uncle, Brown. What Lorraine, what? Oh, if Paul calls me tell him I'm working at the boutique late tonight. Calvin.

    oh yeah, all you gotta do is go over there and ask her. Who are you? Wait a minute. Marty. Marty. Marty. Your not gonna be picking a fight, Dad, dad dad daddy-o. You're coming to a rescue, right? Okay, let's go over the plan again. 8:55, where are you gonna be.

    C'mon man, let's do something that really cooks. The car, Dad, I mean He wrecked it, totaled it. I needed that car tomorrow night, Dad, I mean do you have any idea how important this was, do you have any clue? Roads? Where we're going we don't need roads. Okay. Huh?

    Well that's your name, isn't it? Calvin Klein. it's written all over your underwear. Oh, I guess they call you Cal, huh? I think you got the wrong car, McFly. I'm, I'm sorry, Mr. McFly, I mean, I was just starting on the second coat. Wait a minute, wait a minute, Doc, are you telling me that you built a time machine out of a delorean. I'm writing this down, this is good stuff.

    Ohh, no. Its good. That's right. whoa, this is it, this is the part coming up, Doc. Who?

    Oh, great scott. You get the cable, I'll throw the rope down to you. The future, it's where you're going? I just wanna use the phone. Alright, c'mon, I think we're safe. Take that you mutated son-of-a-bitch. My pine, why you. You space bastard, you killed a pine.

    Doc, Doc, it's me, Marty. Welcome to my latest experiment. It's the one I've been waiting for all my life. Wrecked? Hey c'mon, I had to change, you think I'm going back in that zoot suit? The old man really came through it worked. Good evening, I'm Doctor Emmett Brown. I'm standing on the parking lot of Twin Pines Mall. It's Saturday morning, October 26, 1985, 1:18 a.m. and this is temporal experiment number one. C'mon, Einy, hey hey boy, get in there, that a boy, in you go, get down, that's it.

    Marty, I always wear a suit to the office. You alright? Oh, hi , Marty. I didn't hear you come in. Fascinating device, this video unit. Why am I always the last one to know about these things. he's an idiot, comes from upbringing, parents were probably idiots too. Lorraine, if you ever have a kid like that, I'll disown you. Oh, what I meant to day was-

    George: you ever think of running for class president? Okay, but I don't know what to say. You know, Doc, you left your equipment on all week. Weight has nothing to do with it. Did you hurt your head?

    he's an idiot, comes from upbringing, parents were probably idiots too. Lorraine, if you ever have a kid like that, I'll disown you. Who, who? I don't wanna know your name. I don't wanna know anything anything about you. Oh, what I meant to day was- I guarantee it.

    Yeah, it's 8:00. That's a big bruise you have there. Is she pretty? Oh, then I wanna give her a call, I don't want her to worry about you. Doc, you gotta help-

    He's absolutely right, Marty. the last thing you need is headaches. Well, what if they didn't like them, what if they told me I was no good. I guess that would be pretty hard for somebody to understand. Yeah. You broke it. Wow, look at him go. Uh?

    Why that's me, look at me, I'm an old man. Marty, don't be such a square. Everybody who's anybody drinks. Yeah okay. Where's Einstein, is he with you? Hey you, get your damn hands off, oh.

    Really. Uh listen, do you know where Riverside Drive is? What's that thing he's on? Alright, c'mon, I think we're safe. What, what?

    Check out that four by four. That is hot. Someday, Jennifer, someday. Wouldn't it be great to take that truck up to the lake. Throw a couple of sleeping bags in the back. Lie out under the stars. Yeah, it's 8:00. Don't tell me anything. Can I go now, Mr. Strickland? Marty, you seem so nervous, is something wrong?

    But you're good, Marty, you're really good. And this audition tape of your is great, you gotta send it in to the record company. It's like Doc's always saying. About how far ahead are you going? That's good advice, Marty. Uh, well, I haven't finished those up yet, but you know I figured since they weren't due till- Alright, let's set your destination time. This is the exact time you left. I'm gonna send you back at exactly the same time. It's be like you never left. Now, I painted a white line on the street way over there, that's where you start from. I've calculated the distance and wind resistance fresh to active from the moment the lightning strikes, at exactly 7 minutes and 22 seconds. When this alarm goes off you hit the gas.

    About how far ahead are you going? Great Scott. Let me see that photograph again of your brother. Just as I thought, this proves my theory, look at your brother. Mayor Goldie Wilson, I like the sound of that. Alright, okay. Alright, there she is, George. Just go in there and invite her. That was the day I invented time travel. I remember it vividly. I was standing on the edge of my toilet hanging a clock, the porces was wet, I slipped, hit my head on the edge of the sink. And when I came to I had a revelation, a picture, a picture in my head, a picture of this. This is what makes time travel possible. The flux capacitor.

    whoa, whoa Doc, stuck here, I can't be stuck here, I got a life in 1985. I got a girl. Ahh. Ahh. No. My name's Lorraine, Lorraine Baines. Nothing, nothing, nothing, look tell her destiny has brought you together, tell her that she's the most beautiful you have ever seen. Girls like that stuff. What, what are you doing George?

    You cost three-hundred buck damage to my car, you son-of-a-bitch. And I'm gonna take it out of your ass. Hold him. It was meant to be. Anyway, if Grandpa hadn't hit him, then none of you would have been born. Believe me, Marty, you're better off not having to worry about all the aggravation and headaches of playing at that dance. Bear with me, Marty, all of your questions will be answered. Roll tape, we'll proceed. You cost three-hundred buck damage to my car, you son-of-a-bitch. And I'm gonna take it out of your ass. Hold him.

    I don't worry. this is all wrong. I don't know what it is but when I kiss you, it's like kissing my brother. I guess that doesn't make any sense, does it? You extol me with a lot of confidence, Doc. Alright, c'mon, I think we're safe. Yeah, where does he live? Breakfast.

    David, watch your mouth. You come here and kiss your mother before you go, come here. Ah. In that case, I'll tell you strait out. Uh, Doc. Indeed I will, roll em. I, Doctor Emmett Brown, am about to embark on an historic journey. What have I been thinking of, I almost forgot to bring some extra plutonium. How did I ever expect to get back, one pallet one trip I must be out of my mind. What is it Einy? Oh my god, they found me, I don't know how but they found me. Run for it, Marty.

    Well, uh, listen, uh, I really- Right. Oh, no no no, I never uh, I never let anybody read my stories. Einstein, hey Einstein, where's the Doc, boy, huh? Doc Lorraine, are you up there?

    Of course, from a group of Libyan Nationalists. They wanted me to build them a bomb, so I took their plutonium and in turn gave them a shiny bomb case full of used pinball machine parts. I guarantee it. Of course, from a group of Libyan Nationalists. They wanted me to build them a bomb, so I took their plutonium and in turn gave them a shiny bomb case full of used pinball machine parts. I hope so. Right, gimme a Pepsi free.

    She's just trying to keep you respectable. Well, they're your parents, you must know them. What are their common interests, what do they like to do together? Excuse me. Doc. Time machine, I haven't invented any time machine.

    His head's gone, it's like it's been erased. Oh, just a little weather experiment. Hey, hey listen guys. Look, I don't wanna mess with no reefer addicts, okay? Don't say a word. George, help me, please.

    Hey George, heard you laid out Biff, nice going. That's George McFly. What, what, ma? You wait and see, Mr. Caruthers, I will be mayor and I'll be the most powerful mayor in the history of Hill Valley, and I'm gonna clean up this town. Hey.

    Yeah but George, Lorraine wants to go with you. Give her a break. Doc, Doc, it's me, Marty. What's a rerun? You know what I do in those situations? Where were we.

    Uh, I think so. What about George? Nothing, nothing, nothing, look tell her destiny has brought you together, tell her that she's the most beautiful you have ever seen. Girls like that stuff. What, what are you doing George? Our first television set, Dad just picked it up today. Do you have a television? Alright, okay Jennifer. What if I send in the tape and they don't like it. I mean, what if they say I'm no good. What if they say, 'Get out of here, kid, you got no future.' I mean, I just don't think I can take that kind of rejection. Jesus, I'm beginning to sound like my old man.

    It's information about the future isn't it. I warned you about this kid. The consequences could be disastrous. That's George McFly? Something that really cooks. Alright, alright this is an oldie, but uh, it's an oldie where I come from. Alright guys, let's do some blues riff in b, watch me for the changes, and uh, try and keep up, okay. Okay, real mature guys. Okay, Biff, will you pick up my books? Excuse me.

    Uh, well, okay Biff, uh, I'll finish that on up tonight and I'll bring it over first thing tomorrow morning. Yeah, well, I still don't understand what Dad was doing in the middle of the street. Ronald Reagon. I need fuel. Go ahead, quick, get in the car. whoa, whoa Doc, stuck here, I can't be stuck here, I got a life in 1985. I got a girl.

    It's my dad. you guys look great. Mom, you look so thin. Hello, Jennifer. It's uh, the other end of town, a block past Maple. Who, who?

    Oh, what I meant to day was- That's true, Marty, I think you should spend the night. I think you're our responsibility. C'mon. I have a feeling too. I hope so.

    Lorenzo, where're you keys? Evening, Doctor Brown, what's with the wire? Whoa, this is heavy. C'mon. Hey McFly, what do you think you're doing.

    Doc, wait. No, bastards. Jennifer. Over there, on my hope chest. I've never seen purple underwear before, Calvin. Calm down, Marty, I didn't disintegrate anything. The molecular structure of Einstein and the car are completely intact. Uh, well, okay Biff, uh, I'll finish that on up tonight and I'll bring it over first thing tomorrow morning.

    Oh no, don't touch that. That's some new specialized weather sensing equipment. Say, why do you let those boys push you around like that? What do you mean you've seen this, it's brand new. What did I just say? I'm writing this down, this is good stuff.

    Calvin, why do you keep calling me Calvin? You wanna a Pepsi, pall, you're gonna pay for it. The hell you doing to my car? Uncle Jailbird Joey? Just relax now Calvin, you've got a big bruise on you're head.

    Mom, is that you? Oh, great scott. You get the cable, I'll throw the rope down to you. I can't believe you loaned me a car, without telling me it had a blindspot. I could've been killed. No, no, George, look, it's just an act, right? Okay, so 9:00 you're strolling through the parking lot, you see us struggling in the car, you walk up, you open the door and you say, your line, George. That was so stupid, Grandpa hit him with the car.

    Well, safe and sound, now, n good old 1955. Well, I guess that's everything. That's Strickland. Jesus, didn't that guy ever have hair? Then how am I supposed to ever meet anybody. Yeah, well, I still don't understand what Dad was doing in the middle of the street.

    Hey, hey, Doc, where are you? Right, I got it. Oh, yeah, yeah. Give me a hand, Lorenzo. Ow, dammit, man, I sliced my hand. Hello.

    Kids, we're gonna have to eat this cake by ourselves, Uncle Joey didn't make parole again. I think it would be nice, if you all dropped him a line. Wow, ah Red, you look great. Everything looks great. 1:24, I still got time. Oh my god. No, no not again, c'mon, c'mon. Hey. Libyans. Marty, you made it. Well, Biff. I, I don't know.

    Hey I'm talking to you, McFly, you Irish bug. So you're my Uncle Joey. Better get used to these bars, kid. Take care. Sit here, Marty. But I can't go to the dance, I'll miss my favorite television program, Science Fiction Theater.

    Right about here. Thanks a lot, kid. What did your mother ever see in that kid? Why not? And he could sleep in my room.

    Wow, ah Red, you look great. Everything looks great. 1:24, I still got time. Oh my god. No, no not again, c'mon, c'mon. Hey. Libyans. Yeah, well, how about my homework, McFly? I don't know, I can't keep up with all of your boyfriends. Give me a hand, Lorenzo. Ow, dammit, man, I sliced my hand. Excuse me.

    Hi, Marty. Next, please. I'm sure that in 1985, plutonium is available at every corner drug store, but in 1955, it's a little hard to come by. Marty, I'm sorry, but I'm afraid you're stuck here. Okay. I hope you don't mind but George asked if he could take me home.

    How's your head? Well, she's not doing a very good job. I guarantee it. Oh, yeah, yeah. Watch it, Goldie.

    But I can't go to the dance, I'll miss my favorite television program, Science Fiction Theater. Yeah, well uh, lets keep this brain melting stuff to ourselves, okay? Okay, that's enough. Now stop the microphone. I'm sorry fellas. I'm afraid you're just too darn loud. Next, please. Where's the next group, please. My equipment, that reminds me, Marty, you better not hook up to the amplifier. There's a slight possibility for overload. What, well you mean like a date?

    Hey, Doc? Doc. Hello, anybody home? Einstein, come here, boy. What's going on? Wha- aw, god. Aw, Jesus. Whoa, rock and roll. Yo Keys? There's that word again, heavy. Why are things so heavy in the future. Is there a problem with the Earth's gravitational pull? Good morning, Mom. Oh, Marty, I almost forgot, Jennifer Parker called. Ho ho ho, look at it roll. Now we could watch Jackie Gleason while we eat.

    Radiation suit, of course, cause all of the fall out from the atomic wars. This is truly amazing, a portable television studio. No wonder your president has to be an actor, he's gotta look good on television. Tab? I can't give you a tab unless you order something. George. Thank god I still got my hair. What on Earth is that thing I'm wearing? Oh, I sure like her, Marty, she is such a sweet girl. Isn't tonight the night of the big date?

    George: you ever think of running for class president? Mom, is that you? Don't pay any attention to him, he's in one of his moods. Sam, quit fiddling with that thing, come in here to dinner. Now let's see, you already know Lorraine, this is Milton, this is Sally, that's Toby, and over there in the playpen is little baby Joey. Who is that guy. Why am I always the last one to know about these things.

    Uh, look me up when you get there. Well, bring her along. This concerns her too. Hey, hey listen guys. Look, I don't wanna mess with no reefer addicts, okay? Yeah. Okay, that's enough. Now stop the microphone. I'm sorry fellas. I'm afraid you're just too darn loud. Next, please. Where's the next group, please.

    That's true, Marty, I think you should spend the night. I think you're our responsibility. Ahh. Nothing, nothing, nothing, look tell her destiny has brought you together, tell her that she's the most beautiful you have ever seen. Girls like that stuff. What, what are you doing George? I guess you guys aren't ready for that yet. But your kids are gonna love it. Yeah.

    Marty, one rejection isn't the end of the world. Look me up when you get there, guess I'll be about 47. Well yeah, you know we have two of them. Let's get you into a radiation suit, we must prepare to reload. I don't worry. this is all wrong. I don't know what it is but when I kiss you, it's like kissing my brother. I guess that doesn't make any sense, does it?

    You're gonna break his arm. Biff, leave him alone. Let him go. Let him go. I, I don't know. Breakfast. Don't tell me anything. Save the clock tower.

    George, buddy. remember that girl I introduced you to, Lorraine. What are you writing? Biff, stop it. Biff, you're breaking his arm. Biff, stop. Ah well, sort of. After I fell off my toilet, I drew this. Right, and where am I gonna be?

    Yet. Something that really cooks. Alright, alright this is an oldie, but uh, it's an oldie where I come from. Alright guys, let's do some blues riff in b, watch me for the changes, and uh, try and keep up, okay. What did she say? It's your mom, she's tracked you down. Quick, let's cover the time machine. You're gonna be in the car with her. Right, I got it.

    Over there, on my hope chest. I've never seen purple underwear before, Calvin. Wait a minute, wait a minute, Doc, are you telling me that you built a time machine out of a delorean. No wait, Doc, the bruise, the bruise on your head, I know how that happened, you told me the whole story. you were standing on your toilet and you were hanging a clock, and you fell, and you hit your head on the sink, and that's when you came up with the idea for the flux capacitor, which makes time travel possible. Doc, wait. No, bastards. Good evening, I'm Doctor Emmett Brown. I'm standing on the parking lot of Twin Pines Mall. It's Saturday morning, October 26, 1985, 1:18 a.m. and this is temporal experiment number one. C'mon, Einy, hey hey boy, get in there, that a boy, in you go, get down, that's it.

    God dammit, I'm late. You know Marty, I'm gonna be very sad to see you go. You've really mad a difference in my life, you've given me something to shoot for. Just knowing, that I'm gonna be around to se 1985, that I'm gonna succeed in this. That I'm gonna have a chance to travel through time. It's going to be really hard waiting 30 years before I could talk to you about everything that's happened in the past few days. I'm really gonna miss you, Marty. Jennifer. Good evening, I'm Doctor Emmett Brown. I'm standing on the parking lot of Twin Pines Mall. It's Saturday morning, October 26, 1985, 1:18 a.m. and this is temporal experiment number one. C'mon, Einy, hey hey boy, get in there, that a boy, in you go, get down, that's it. Well looky what we have here. No no no, you're staying right here with me.

    Einstein, hey Einstein, where's the Doc, boy, huh? Doc Uh, you mean nobody's asked you? Watch it, Goldie. Look, there's a rhythmic ceremonial ritual coming up. Something that really cooks. Alright, alright this is an oldie, but uh, it's an oldie where I come from. Alright guys, let's do some blues riff in b, watch me for the changes, and uh, try and keep up, okay.

    Oh, oh Marty, here's your keys. You're all waxed up, ready for tonight. Biff. Hey, hey, keep rolling, keep rolling there. No, no, no, no, this sucker's electrical. But I need a nuclear reaction to generate the one point twenty-one gigawatts of electricity that I need. No, no, George, look, it's just an act, right? Okay, so 9:00 you're strolling through the parking lot, you see us struggling in the car, you walk up, you open the door and you say, your line, George. Yes, yes, I'm George, George McFly, and I'm your density. I mean, I'm your destiny.

    Hey, hey, Doc, where are you? Doc. Yeah, I think it's a major embarrassment having an uncle in prison. I over slept, look I need your help. I have to ask Lorraine out but I don't know how to do it. I have to ask Lorraine out but I don't know how to do it. Hey c'mon, I had to change, you think I'm going back in that zoot suit? The old man really came through it worked.

    It's my dad. Without any sugar. Right, and where am I gonna be? Listen, Doc. Uh, coast guard.

    Oh Mom, there's nothing wrong with calling a boy. Something that really cooks. Alright, alright this is an oldie, but uh, it's an oldie where I come from. Alright guys, let's do some blues riff in b, watch me for the changes, and uh, try and keep up, okay. Anyway, Grandpa hit him with the car and brought him into the house. He seemed so helpless, like a little lost puppy, my heart just went out for him. Let's go. Uh, well, I haven't finished those up yet, but you know I figured since they weren't due till-

    You bet. Over there, on my hope chest. I've never seen purple underwear before, Calvin. What? Well, safe and sound, now, n good old 1955. Uncle Jailbird Joey?

    I'm sure that in 1985, plutonium is available at every corner drug store, but in 1955, it's a little hard to come by. Marty, I'm sorry, but I'm afraid you're stuck here. George. Oh yes sir. Lorraine. Well, Marty, I want to thank you for all your good advice, I'll never forget it.

    Shut your filthy mouth, I'm not that kind of girl. Yeah, I guessed you're a sailor, aren't you, that's why you wear that life preserver. Whoa, wait, Doc. Now, of course not, Biff, now, I wouldn't want that to happen. No no no this sucker's electrical, but I need a nuclear reaction to generate the one point twenty-one gigawatts of electricity-

    Don't stop, Wilbert, drive. This is uh, this is heavy duty, Doc, this is great. Uh, does it run on regular unleaded gasoline? He's a very strange young man. I'm telling the truth, Doc, you gotta believe me. Excuse me.

    Look me up when you get there, guess I'll be about 47. He's a very strange young man. Yeah. Take that you mutated son-of-a-bitch. My pine, why you. You space bastard, you killed a pine. Oh, yeah, yeah.

    Don't worry, I'll take care of the lightning, you take care of your pop. By the way, what happened today, did he ask her out? Ahh. Okay. Hey man, look at Marvin's hand. He can't play with his hands like that, and we can't play without him. I think I know exactly what you mean.

    No, Biff, you leave her alone. Yeah Mom, we know, you've told us this story a million times. You felt sorry for him so you decided to go with him to The Fish Under The Sea Dance. Okay, real mature guys. Okay, Biff, will you pick up my books? Ahh. Thanks.

    Dear Doctor Brown, on the night that I go back in time, you will be shot by terrorists. Please take whatever precautions are necessary to prevent this terrible disaster. Your friend, Marty. Let's go. Cause, George, she wants to go to the dance with you, she just doesn't know it yet. That's why we got to show her that you, George McFly, are a fighter. You're somebody who's gonna stand up for yourself, someone who's gonna protect her. Listen, Doc. Y'know this time it wasn't my fault. The Doc set all of his clocks twenty-five minutes slow.

    You wanna a Pepsi, pall, you're gonna pay for it. Our first television set, Dad just picked it up today. Do you have a television? You do? Oh. My god, it's my mother. Put your pants back on.

    Breakfast. Now, Biff, um, can I assume that your insurance is gonna pay for the damage? Indeed I will, roll em. I, Doctor Emmett Brown, am about to embark on an historic journey. What have I been thinking of, I almost forgot to bring some extra plutonium. How did I ever expect to get back, one pallet one trip I must be out of my mind. What is it Einy? Oh my god, they found me, I don't know how but they found me. Run for it, Marty. So tell me, Marty, how long have you been in port? Which one's your pop?

    Ahh. I'm too loud. I can't believe it. I'm never gonna get a chance to play in front of anybody. It's already mutated into human form, shoot it. What, what, ma? You know, Doc, you left your equipment on all week.

    Sam, here's the young man you hit with your car out there. He's alright, thank god. you guys look great. Mom, you look so thin. It's about the future, isn't it? Is she pretty? It's taken me almost thirty years and my entire family fortune to realize the vision of that day, my god has it been that long. Things have certainly changed around here. I remember when this was all farmland as far as the eye could see. Old man Peabody, owned all of this. He had this crazy idea about breeding pine trees.

    Shut your filthy mouth, I'm not that kind of girl. Wow, you must be rich. His head's gone, it's like it's been erased. A colored mayor, that'll be the day. Yeah, I guessed you're a sailor, aren't you, that's why you wear that life preserver.

    Right. Listen, this is very important, I forgot my video camera, could you stop by my place and pick it up on your way to the mall? I'm really gonna miss you. Doc, about the future- Huh? Um, well it's a delorean, right?

    Over there, on my hope chest. I've never seen purple underwear before, Calvin. Right. Lou, gimme a milk, chocolate. Lorraine, my density has popped me to you. Save the clock tower, save the clock tower. Mayor Wilson is sponsoring an initiative to replace that clock. Thirty years ago, lightning struck that clock tower and the clock hasn't run since. We at the Hill Valley Preservation Society think it should be preserved exactly the way it is as part of our history and heritage. I think it's terrible. Girls chasing boys. When I was your age I never chased a boy, or called a boy, or sat in a parked car with a boy. Breakfast.

    Well, what if they didn't like them, what if they told me I was no good. I guess that would be pretty hard for somebody to understand. No, no, George, look, it's just an act, right? Okay, so 9:00 you're strolling through the parking lot, you see us struggling in the car, you walk up, you open the door and you say, your line, George. Thank god I still got my hair. What on Earth is that thing I'm wearing? I hope you don't mind but George asked if he could take me home. He's a very strange young man.

    Right, I got it. That's Strickland. Jesus, didn't that guy ever have hair? That was the day I invented time travel. I remember it vividly. I was standing on the edge of my toilet hanging a clock, the porces was wet, I slipped, hit my head on the edge of the sink. And when I came to I had a revelation, a picture, a picture in my head, a picture of this. This is what makes time travel possible. The flux capacitor. Just finishing up the second coat now. Mr. McFly, Mr. McFly, this just arrived, oh hi Marty. I think it's your new book.

    Yeah. What, what? Marty, will we ever see you again? Marty, are you alright? Your not gonna be picking a fight, Dad, dad dad daddy-o. You're coming to a rescue, right? Okay, let's go over the plan again. 8:55, where are you gonna be.

    You extol me with a lot of confidence, Doc. Doc. Listen, woh. Hello, uh excuse me. Sorry about your barn. Hey, hey, keep rolling, keep rolling there. No, no, no, no, this sucker's electrical. But I need a nuclear reaction to generate the one point twenty-one gigawatts of electricity that I need. Evening, Doctor Brown, what's with the wire?

    But, what are you blind McFly, it's there. How else do you explain that wreck out there? Doc, Doc. Oh, no. You're alive. Bullet proof vest, how did you know, I never got a chance to tell you. About all that talk about screwing up future events, the space time continuum. Okay, alright, I'll prove it to you. Look at my driver's license, expires 1987. Look at my birthday, for crying out load I haven't even been born yet. And, look at this picture, my brother, my sister, and me. Look at the sweatshirt, Doc, class of 1984. Why do you keep following me around? Hey beat it, spook, this don't concern you.

    Because, you might regret it later in life. You do? Yoo. Hello. Keys?

    Yoo. Uh, well, actually, I figured since it wasn't due till Monday- Why is she gonna get angry with you? Doc, she's beautiful. She's crazy about me. Look at this, look what she wrote me, Doc. That says it all. Doc, you're my only hope. What?

    Ronald Reagon, the actor? Then who's vice president, Jerry Lewis? I suppose Jane Wymann is the first lady. I'll call you tonight. After I fell off my toilet, I drew this. C'mon, he's not that bad. At least he's letting you borrow the car tomorrow night. Alright, I'm ready.

    Oh, great scott. You get the cable, I'll throw the rope down to you. What? Marty, I'm sorry, but the only power source capable of generating one point twenty-one gigawatts of electricity is a bolt of lightning. Yeah but George, Lorraine wants to go with you. Give her a break. Actually, people call me Marty.

    whoa, whoa Doc, stuck here, I can't be stuck here, I got a life in 1985. I got a girl. Mom, Dad. Dear Doctor Brown, on the night that I go back in time, you will be shot by terrorists. Please take whatever precautions are necessary to prevent this terrible disaster. Your friend, Marty. I know, and all I could say is I'm sorry. No no. Lorraine, Lorraine, what are you doing?

    It's about the future, isn't it? Your, your right. Something wrong with the starter, so I hid it. You extol me with a lot of confidence, Doc. She's just trying to keep you respectable.

    Doc, you gotta help me. you were the only one who knows how your time machine works. Oh, oh a rematch, why, were you cheating? Alright, we're the pinheads. Where were we. Of course, the Enchantment Under The Sea Dance they're supposed to go to this, that's where they kiss for the first time.

    Well, bring her along. This concerns her too. Listen, Doc, you know there's something I haven't told you about the night we made that tape. Good. Have a good trip Einstein, watch your head. This is uh, this is heavy duty, Doc, this is great. Uh, does it run on regular unleaded gasoline? I think it's terrible. Girls chasing boys. When I was your age I never chased a boy, or called a boy, or sat in a parked car with a boy.

    That's George McFly. Kids, we're gonna have to eat this cake by ourselves, Uncle Joey didn't make parole again. I think it would be nice, if you all dropped him a line. You wanna a Pepsi, pall, you're gonna pay for it. Ah. Can't be. This is nuts. Aw, c'mon.

    Oh no, don't touch that. That's some new specialized weather sensing equipment. Wait a minute, what are you doing, Doc? Yeah well look, Marvin, Marvin, you gotta play. See that's where they kiss for the first time on the dance floor. And if there's no music, they can't dance, and if they can't dance, they can't kiss, and if they can't kiss, they can't fall in love and I'm history. Yes, yes, I'm George, George McFly, and I'm your density. I mean, I'm your destiny. Radiation suit, of course, cause all of the fall out from the atomic wars. This is truly amazing, a portable television studio. No wonder your president has to be an actor, he's gotta look good on television.

    It's already mutated into human form, shoot it. Yeah, exactly. Yoo. Marty. Marty. Marty. Doc.

    Ahh. Save the clock tower, save the clock tower. Mayor Wilson is sponsoring an initiative to replace that clock. Thirty years ago, lightning struck that clock tower and the clock hasn't run since. We at the Hill Valley Preservation Society think it should be preserved exactly the way it is as part of our history and heritage. Now which one was it, Greg or Craig? Look, there's a rhythmic ceremonial ritual coming up. That's Strickland. Jesus, didn't that guy ever have hair?

    You know Marty, you look so familiar, do I know your mother? No no no this sucker's electrical, but I need a nuclear reaction to generate the one point twenty-one gigawatts of electricity- Dear Doctor Brown, on the night that I go back in time, you will be shot by terrorists. Please take whatever precautions are necessary to prevent this terrible disaster. Your friend, Marty. What? Anyway, Grandpa hit him with the car and brought him into the house. He seemed so helpless, like a little lost puppy, my heart just went out for him.

    Look, there's a rhythmic ceremonial ritual coming up. Alright, okay Jennifer. What if I send in the tape and they don't like it. I mean, what if they say I'm no good. What if they say, 'Get out of here, kid, you got no future.' I mean, I just don't think I can take that kind of rejection. Jesus, I'm beginning to sound like my old man. What a nightmare. What the hell is a gigawatt? Oh.

    No, Doc. It's cold, damn cold. Ha, ha, ha, Einstein, you little devil. Einstein's clock is exactly one minute behind mine, it's still ticking. Yeah, well, I still don't understand what Dad was doing in the middle of the street. Keys? Ahh.

    Well that's your name, isn't it? Calvin Klein. it's written all over your underwear. Oh, I guess they call you Cal, huh? He's an absolute dream. Right, I got it. Just turn around, McFly, and walk away. Are you deaf, McFly? Close the door and beat it. Evening, Doctor Brown, what's with the wire?

    Well, aren't you going up to the lake tonight, you've been planning it for two weeks. Huh? Ah, honey, your first novel. Save the clock tower. C'mon.

    The car, Dad, I mean He wrecked it, totaled it. I needed that car tomorrow night, Dad, I mean do you have any idea how important this was, do you have any clue? Doc. Hey George, heard you laid out Biff, nice going. Ronald Reagon. I just wanna use the phone.

    Ho, you mean you're gonna touch her on her- Biff, stop it. Biff, you're breaking his arm. Biff, stop. I'm really gonna miss you. Doc, about the future- We do now. Dear Doctor Brown, on the night that I go back in time, you will be shot by terrorists. Please take whatever precautions are necessary to prevent this terrible disaster. Your friend, Marty.

    Lynda, first of all, I'm not your answering service. Second of all, somebody named Greg or Craig called you just a little while ago. Mom, Dad. No, why, what's a matter? Y'know this time it wasn't my fault. The Doc set all of his clocks twenty-five minutes slow. Uh, coast guard.

    I'm really gonna miss you. Doc, about the future- This is for all you lovers out there. You know Marty, I'm gonna be very sad to see you go. You've really mad a difference in my life, you've given me something to shoot for. Just knowing, that I'm gonna be around to se 1985, that I'm gonna succeed in this. That I'm gonna have a chance to travel through time. It's going to be really hard waiting 30 years before I could talk to you about everything that's happened in the past few days. I'm really gonna miss you, Marty. That's Strickland. Jesus, didn't that guy ever have hair? What, what, ma?

    You extol me with a lot of confidence, Doc. Um, yeah, I'm on my way. And he could sleep in my room. Look, you gotta listen to me. Please note that Einstein's clock is in complete synchronization with my control watch.

    His head's gone, it's like it's been erased. Right. Hey beat it, spook, this don't concern you. I need fuel. Go ahead, quick, get in the car. Alright, take it up, go. Doc.

    How could I have been so careless. One point twenty-one gigawatts. Tom, how am I gonna generate that kind of power, it can't be done, it can't. I followed you. Please, Marty, don't tell me, no man should know too much about their own destiny. Hello. Now, Biff, um, can I assume that your insurance is gonna pay for the damage?

    Yeah, gimme a Tab. Listen, I gotta go but I wanted to tell you that it's been educational. Well, it will just happen. Like the way I met your father. What? Oh, oh Marty, here's your keys. You're all waxed up, ready for tonight.

    It's a board with wheels. Whoa, this is heavy. Now which one was it, Greg or Craig? You can't, uh, that is, uh, nobody's home. C'mon.

    How about a ride, Mister? Science Fiction Theater. Don't stop, Wilbert, drive. You heard her she said get your meat hooks, off, uh please. Okay.

    Right. He's a peeping tom. Dad. Because, you might regret it later in life. Welcome to my latest experiment. It's the one I've been waiting for all my life. Jennifer.

    No, Doc. And where's my reports? Who? It's my dad. Doc, you don't just walk into a store and ask for plutonium. Did you rip this off?

    Hey beat it, spook, this don't concern you. Why thank you, Marty. George. Good morning, sleepyhead, Good morning, Dave, Lynda I guess you guys aren't ready for that yet. But your kids are gonna love it. Well, ma, we talked about this, we're not gonna go to the lake, the car's wrecked. Well, they're bigger than me.

    Right, gimme a Pepsi free. Just turn around, McFly, and walk away. Are you deaf, McFly? Close the door and beat it. Ahh. Thanks a lot, kid. Uh listen, do you know where Riverside Drive is?

    What? You can't, uh, that is, uh, nobody's home. Doc, is that a de- Great good, good, Lorraine, I had a feeling about you two. Right.

    Well, uh, listen, uh, I really- Yeah well look, Marvin, Marvin, you gotta play. See that's where they kiss for the first time on the dance floor. And if there's no music, they can't dance, and if they can't dance, they can't kiss, and if they can't kiss, they can't fall in love and I'm history. You bet. You'll find out. Quiet down, I'm sure the car is fine.

    Yeah, I'm- mayor. Now that's a good idea. I could run for mayor. Ah well, sort of. George, help me, please. whoa, this is it, this is the part coming up, Doc. Well, they're bigger than me.

    Uh no, not hard at all. So anyway, George, now Lorraine, she really likes you. She told me to tell you that she wants you to ask her to the Enchantment Under The Sea Dance. Are you gonna order something, kid? Alright, I'm ready. Ohh, no. Huh?

    George, aren't you gonna kiss me? You too. No no no, Doc, I just got here, okay, Jennifer's here, we're gonna take the new truck for a spin. Alright, I'm ready. Yeah but George, Lorraine wants to go with you. Give her a break.

    Hey man, the dance is over. Unless you know someone else who could play the guitar. It's uh, the other end of town, a block past Maple. Yes, yes, I'm George, George McFly, and I'm your density. I mean, I'm your destiny. Doc, look, all we need is a little plutonium. Shape up, man. You're a slacker. You wanna be a slacker for the rest of your life?

    No no no this sucker's electrical, but I need a nuclear reaction to generate the one point twenty-one gigawatts of electricity that I need. Welcome to my latest experiment. It's the one I've been waiting for all my life. That's him. You'll find out. But you're good, Marty, you're really good. And this audition tape of your is great, you gotta send it in to the record company. It's like Doc's always saying.

    Why not? Who are you calling spook, pecker-wood. I'm gonna be at the dance. Its good. Of course, the Enchantment Under The Sea Dance they're supposed to go to this, that's where they kiss for the first time.

    Yeah, I guessed you're a sailor, aren't you, that's why you wear that life preserver. Is she pretty? Oh hey, Biff, hey, guys, how are you doing? Let's put him in there. Hey kid, what you do, jump ship?

    Hot, Jesus Christ, Doc. Jesus Christ, Doc, you disintegrated Einstein. Let's put him in there. Mayor Goldie Wilson, I like the sound of that. Good morning, Mom. Oh, Marty, I almost forgot, Jennifer Parker called. No, Marty, we've already agreed that having information about the future could be extremely dangerous. Even if your intentions are good, they could backfire drastically. Whatever you've got to tell me I'll find out through the natural course of time.

    Excuse me. Why thank you, Marty. George. Good morning, sleepyhead, Good morning, Dave, Lynda Oh, just a little weather experiment. I will. Hello.

    Are you okay? Well, ma, we talked about this, we're not gonna go to the lake, the car's wrecked. Oh, I've been so worried about you ever since you ran off the other night. Are you okay? I'm sorry I have to go. Isn't he a dream boat? They're late. My experiment worked. They're all exactly twenty-five minutes slow. You cost three-hundred buck damage to my car, you son-of-a-bitch. And I'm gonna take it out of your ass. Hold him.

    Wrecked? Where does he come from? Yeah. The only way we're gonna get those two to successfully meet is if they're alone together. So you've got to get your father and mother to interact at some sort of social- Oh honey, he's teasing you, nobody has two television sets.

    Thank god I found you. Listen, can you meet me at Twin Pines Mall tonight at 1:15? I've made a major breakthrough, I'll need your assistance. Huh? Thank god I still got my hair. What on Earth is that thing I'm wearing? You got a real attitude problem, McFly. You're a slacker. You remind me of you father when he went her, he was a slacker too. Give me a hand, Lorenzo. Ow, dammit, man, I sliced my hand.

    Shut your filthy mouth, I'm not that kind of girl. Oh, I sure like her, Marty, she is such a sweet girl. Isn't tonight the night of the big date? What's a rerun? What Lorraine, what? Oh.

    How's your head? That's for messing up my hair. Why thank you, Marty. George. Good morning, sleepyhead, Good morning, Dave, Lynda Hey boy, are you alright? What kind of date? I don't know, what do kids do in the fifties?

    Go. Marty, are you alright? Marty, you made it. Uh, Doc. Don't say a word.

    Marty, that's completely out of the question, you must not leave this house. you must not see anybody or talk to anybody. Anything you do could have serious repercussions on future events. Do you understand? You're gonna be in the car with her. Look, there's a rhythmic ceremonial ritual coming up. Damn. I'm late for school. You don't understand.

    David, watch your mouth. You come here and kiss your mother before you go, come here. Give me a hand, Lorenzo. Ow, dammit, man, I sliced my hand. C'mon man, let's do something that really cooks. Oh. Check out that four by four. That is hot. Someday, Jennifer, someday. Wouldn't it be great to take that truck up to the lake. Throw a couple of sleeping bags in the back. Lie out under the stars.

    You'll find out. C'mon, c'mon. Well, aren't you going up to the lake tonight, you've been planning it for two weeks. Ronald Reagon, the actor? Then who's vice president, Jerry Lewis? I suppose Jane Wymann is the first lady. Oh, pleased to meet you, Calvin Marty Klein. Do you mind if I sit here?

    Ahh. Yeah, alright, bye-bye. What? Oh Mom, there's nothing wrong with calling a boy. Alright kid, you stick to your father like glue and make sure that he takes her to the dance. I gotta go, uh, I gotta go. Thanks very much, it was wonderful, you were all great. See you all later, much later.

    Marty, that was very interesting music. Just finishing up the second coat now. Oh, oh Marty, here's your keys. You're all waxed up, ready for tonight. Marty, that was very interesting music. Hey, hey listen guys. Look, I don't wanna mess with no reefer addicts, okay?

    Actually, people call me Marty. This Saturday night, mostly clear, with some scattered clouds. Lows in the upper forties. Let's go. The car, Dad, I mean He wrecked it, totaled it. I needed that car tomorrow night, Dad, I mean do you have any idea how important this was, do you have any clue? Jennifer, oh are you a sight for sore eyes. Let me look at you.

    Good morning, Mom. Mother, with Marty's parents out of town, don't you think he oughta spend the night, after all, Dad almost killed him with the car. Just turn around, McFly, and walk away. Are you deaf, McFly? Close the door and beat it. Hey man, the dance is over. Unless you know someone else who could play the guitar. Why is she gonna get angry with you?

    So what's it to you, butthead. You know you've been looking for a, since you're new here, I'm gonna cut you a break, today. So why don't you make like a tree, and get out of here. Then how am I supposed to ever meet anybody. Children. A bolt of lightning, unfortunately, you never know when or where it's ever gonna strike. Do you mind if we park for a while?

    What did you sleep in your clothes again last night. Jennifer. I swiped it from the old lady's liquor cabinet. Well, safe and sound, now, n good old 1955. I can't believe you loaned me a car, without telling me it had a blindspot. I could've been killed.

    There's that word again, heavy. Why are things so heavy in the future. Is there a problem with the Earth's gravitational pull? Ah, where're my pants? Don't pay any attention to him, he's in one of his moods. Sam, quit fiddling with that thing, come in here to dinner. Now let's see, you already know Lorraine, this is Milton, this is Sally, that's Toby, and over there in the playpen is little baby Joey. Hey, George, buddy, you weren't at school, what have you been doing all day? Whoa, this is heavy.

    Doc? I noticed you band is on the roster for dance auditions after school today. Why even bother Mcfly, you haven't got a chance, you're too much like your own man. No McFly ever amounted to anything in the history of Hill Valley. Uh, Doc. Well, bring her along. This concerns her too. Hi, Marty.

    I don't wanna see you in here again. David, watch your mouth. You come here and kiss your mother before you go, come here. I do understand. If I know too much about my own future I could endanger my own existence, just as you endangered yours. No, not yet. You know, Doc, you left your equipment on all week.

    Now, Biff, um, can I assume that your insurance is gonna pay for the damage? You have this thing hooked up to the car? What were you doing in the middle of the street, a kid your age. No, bastards. Hey, hey, I've seen this one, I've seen this one. This is a classic, this is where Ralph dresses up as the man from space.

    Okay Doc, this is it. I got enough practical jokes for one evening. Good night, future boy. Will you take care of that? This is it. This is the answer. It says here that a bolt of lightning is gonna strike the clock tower precisely at 10:04 p.m. next Saturday night. If we could somehow harness this bolt of lightning, channel it into the flux capacitor, it just might work. Next Saturday night, we're sending you back to the future. Okay, but I don't know what to say.

    you guys look great. Mom, you look so thin. Oh, hi , Marty. I didn't hear you come in. Fascinating device, this video unit. Alright kid, you stick to your father like glue and make sure that he takes her to the dance. Lorraine, are you up there? Go. Go.

    Uh, well, okay Biff, uh, I'll finish that on up tonight and I'll bring it over first thing tomorrow morning. Uh Doc, uh no. No, don't be silly. Right. Well, she's not doing a very good job. Why is she gonna get angry with you?

    Oh, pleased to meet you, Calvin Marty Klein. Do you mind if I sit here? Don't tell me. Uh, you want me to buy a subscription to the Saturday Evening Post? Do you mind if we park for a while? Right. I can't play.

    Do you mind if we park for a while? Yeah, well, how about my homework, McFly? The car, Dad, I mean He wrecked it, totaled it. I needed that car tomorrow night, Dad, I mean do you have any idea how important this was, do you have any clue? Uh, you mean nobody's asked you? Hey McFly, what do you think you're doing.

    Unfortunately no, it requires something with a little more kick, plutonium. Doc. Hey, Doc? Doc. Hello, anybody home? Einstein, come here, boy. What's going on? Wha- aw, god. Aw, Jesus. Whoa, rock and roll. Yo Right. Well, uh, listen, uh, I really-

    Hi, it's really a pleasure to meet you. Huh? Biff, stop it. Biff, you're breaking his arm. Biff, stop. Ah. Whoa. Well, this is a radiation suit.

    Wait a minute, wait a minute, Doc, are you telling me that you built a time machine out of a delorean. Crazy drunk drivers. Yeah, I guessed you're a sailor, aren't you, that's why you wear that life preserver. The way I see it, if you're gonna build a time machine into a car why not do it with some style. Besides, the stainless, steel construction made the flux dispersal- look out. Don't say a word.

    Then how am I supposed to ever meet anybody. Well, what if they didn't like them, what if they told me I was no good. I guess that would be pretty hard for somebody to understand. Well, bring her along. This concerns her too. No no. Lorraine, Lorraine, what are you doing? Are those my clocks I hear?

    Hey boy, are you alright? What's a rerun? About 30 years, it's a nice round number. Huh? But you're good, Marty, you're really good. And this audition tape of your is great, you gotta send it in to the record company. It's like Doc's always saying.

    We're gonna take a little break but we'll be back in a while so, don't nobody go no where. Einstein, hey Einstein, where's the Doc, boy, huh? Doc Dear Doctor Brown, on the night that I go back in time, you will be shot by terrorists. Please take whatever precautions are necessary to prevent this terrible disaster. Your friend, Marty. The flux capacitor. We never would have fallen in love.

    Marty, one rejection isn't the end of the world. Okay, alright, Saturday is good, Saturday's good, I could spend a week in 1955. I could hang out, you could show me around. I know what you're gonna say, son, and you're right, you're right, But Biff just happens to be my supervisor, and I'm afraid I'm not very good at confrontations. Why do you keep following me around? Stop it.

    Thanks, thanks a lot. You have this thing hooked up to the car? The keys are in the trunk. I don't like her, Marty. Any girl who calls a boy is just asking for trouble. Last night, Darth Vader came down from planet Vulcan. And he told me that if I didn't take Lorraine, that he'd melt my brain.

    I got enough practical jokes for one evening. Good night, future boy. Because, you might regret it later in life. Marty you gotta come back with me. No, Marty, we've already agreed that having information about the future could be extremely dangerous. Even if your intentions are good, they could backfire drastically. Whatever you've got to tell me I'll find out through the natural course of time. No, no, George, look, it's just an act, right? Okay, so 9:00 you're strolling through the parking lot, you see us struggling in the car, you walk up, you open the door and you say, your line, George.

    Oh, I've been so worried about you ever since you ran off the other night. Are you okay? I'm sorry I have to go. Isn't he a dream boat? Ahh. Can I go now, Mr. Strickland? Well, Marty, I want to thank you for all your good advice, I'll never forget it. Wait a minute, wait a minute, Doc, are you telling me that you built a time machine out of a delorean.

    Oh, oh a rematch, why, were you cheating? No no no, Doc, I just got here, okay, Jennifer's here, we're gonna take the new truck for a spin. Sit here, Marty. What's a rerun? It's already mutated into human form, shoot it.

    you guys look great. Mom, you look so thin. I haven't No. yes, Joey just loves being in his playpen. he cries whenever we take him out so we just leave him in there all the time. Well Marty, I hope you like meatloaf. Are you okay?

    I know what you're gonna say, son, and you're right, you're right, But Biff just happens to be my supervisor, and I'm afraid I'm not very good at confrontations. The keys are in the trunk. I hope so. C'mon, c'mon let's go. You don't understand.

    A colored mayor, that'll be the day. He's your brother, Mom. Good, you could start by sweeping the floor. I don't know, but I'm gonna find out. No no no this sucker's electrical, but I need a nuclear reaction to generate the one point twenty-one gigawatts of electricity-

    No. Why am I always the last one to know about these things. Give me a hand, Lorenzo. Ow, dammit, man, I sliced my hand. We do now. Well, Marty, I'm almost eighteen-years-old, it's not like I've never parked before.

    Hey, hey, Doc, where are you? Oh yes sir. My god, it's my mother. Put your pants back on. Wait a minute. Wait a minute, Doc. Are you telling me that it's 8:25? Give me a hand, Lorenzo. Ow, dammit, man, I sliced my hand.

    Now, of course not, Biff, now, I wouldn't want that to happen. Well gee, I don't know. Well, because George, nice girls get angry when guys take advantage of them. No, fine, no , good, fine, good. Now remember, according to my theory you interfered with with your parent's first meeting. They don't meet, they don't fall in love, they won't get married and they wont have kids. That's why your older brother's disappeared from that photograph. Your sister will follow and unless you repair the damages, you will be next.

    Ah. Whoa. Lorenzo, where're you keys? Uh, Doc. Now, of course not, Biff, now, I wouldn't want that to happen. Yeah, who are you?

    Shit. Alright, alright, okay McFly, get a grip on yourself. It's all a dream. Just a very intense dream. Woh, hey, listen, you gotta help me. Hi, it's really a pleasure to meet you. What? Why thank you, Marty. George. Good morning, sleepyhead, Good morning, Dave, Lynda

    I don't like her, Marty. Any girl who calls a boy is just asking for trouble. Yeah. Okay, that's enough. Now stop the microphone. I'm sorry fellas. I'm afraid you're just too darn loud. Next, please. Where's the next group, please. Nah, I just don't think I'm cut out for music. Back to the future.

    Where does he come from? Okay, real mature guys. Okay, Biff, will you pick up my books? No, fine, no , good, fine, good. Please note that Einstein's clock is in complete synchronization with my control watch. I think it's terrible. Girls chasing boys. When I was your age I never chased a boy, or called a boy, or sat in a parked car with a boy.

    Look, George, I'm telling you George, if you do not ask Lorraine to that dance, I'm gonna regret it for the rest of my life. Right about here. Hey, hey, Doc, where are you? Okay, but I don't know what to say. My equipment, that reminds me, Marty, you better not hook up to the amplifier. There's a slight possibility for overload.

    What were you doing in the middle of the street, a kid your age. Where? Pa, what is it? What is it, Pa? Flux capacitor. You wait and see, Mr. Caruthers, I will be mayor and I'll be the most powerful mayor in the history of Hill Valley, and I'm gonna clean up this town.

    Go. What's going on? Where have you been all week? I don't know, Doc, I guess she felt sorry for him cause her did hit him with the car, hit me with the car. Yeah I know, If you put your mind to it you could accomplish anything. What's that thing he's on?

    Hey, hey, I've seen this one, I've seen this one. This is a classic, this is where Ralph dresses up as the man from space. Hello, hello, anybody home? Think, McFly, think. I gotta have time to recopy it. Do your realize what would happen if I hand in my homework in your handwriting? I'd get kicked out of school. You wouldn't want that to happen would you, would you? Why is she gonna get angry with you? No sir, I'm gonna make something out of myself, I'm going to night school and one day I'm gonna be somebody. I think it's terrible. Girls chasing boys. When I was your age I never chased a boy, or called a boy, or sat in a parked car with a boy.

    Back to the future. Uh, no, no, no, no. What are you looking at, butt-head? You too. Ahh. Yeah man, that was good. Let's do another one.

    I know what you're gonna say, son, and you're right, you're right, But Biff just happens to be my supervisor, and I'm afraid I'm not very good at confrontations. Well uh, good, fine. Alright, take it up, go. Doc. Believe me, Marty, you're better off not having to worry about all the aggravation and headaches of playing at that dance. Listen, Doc.

    I don't know, but I'm gonna find out. I'm too loud. I can't believe it. I'm never gonna get a chance to play in front of anybody. I had a horrible nightmare, dreamed I went back in time, it was terrible. No. You're gonna break his arm. Biff, leave him alone. Let him go. Let him go.

  NOWDOCPHP73;
    }
}

class ClassAfterLongNowDoc
{
}
